@@ -42,7 +42,7 @@ Activity::Activity(
 	int _activityGroupId,
 	const QStringList& _teachersNames,
 	const QString& _subjectName,
-	const QString& _subjectTagName,
+	const QString& _activityTagName,
 	const QStringList& _studentsNames,
 	int _duration,
 	int _totalDuration,
@@ -54,7 +54,7 @@ Activity::Activity(
 	this->activityGroupId=_activityGroupId;
 	this->teachersNames = _teachersNames;
 	this->subjectName = _subjectName;
-	this->subjectTagName = _subjectTagName;
+	this->activityTagName = _activityTagName;
 	this->studentsNames = _studentsNames;
 	this->duration=_duration;
 	this->totalDuration=_totalDuration;
@@ -81,7 +81,7 @@ bool Activity::operator==(Activity& a)
 		return false;
 	if(this->subjectName != a.subjectName)
 		return false;
-	if(this->subjectTagName != a.subjectTagName)
+	if(this->activityTagName != a.activityTagName)
 		return false;
 	if(this->studentsNames != a.studentsNames)
 		return false;
@@ -167,7 +167,8 @@ void Activity::computeInternalStructure(Rules& r)
 	//the internal subgroups list must be computed before entering here.
 
 	//teachers
-	this->nTeachers=0;
+	//this->nTeachers=0;
+	this->iTeachersList.clear();
 	for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++){
 		int tmp;
 		for(tmp=0; tmp<r.nInternalTeachers; tmp++){
@@ -175,33 +176,38 @@ void Activity::computeInternalStructure(Rules& r)
 				break;
 		}
 		assert(tmp < r.nInternalTeachers);
-		assert(this->nTeachers<MAX_TEACHERS_PER_ACTIVITY);
-		this->teachers[this->nTeachers++]=tmp;
+		//assert(this->nTeachers<MAX_TEACHERS_PER_ACTIVITY);
+		//this->teachers[this->nTeachers++]=tmp;
+		this->iTeachersList.append(tmp);
 	}
 
 	//subjects
 	this->subjectIndex = r.searchSubject(this->subjectName);
 	assert(this->subjectIndex>=0);
 
-	//subject tags
-	this->subjectTagIndex = r.searchSubjectTag(this->subjectTagName);
+	//activity tags
+	this->activityTagIndex = r.searchActivityTag(this->activityTagName);
 
 	//students	
-	this->nSubgroups=0;
+	//this->nSubgroups=0;
+	this->iSubgroupsList.clear();
 	for(QStringList::Iterator it=this->studentsNames.begin(); it!=this->studentsNames.end(); it++){
-		StudentsSet* ss=r.searchStudentsSet(*it);
+		StudentsSet* ss=r.searchAugmentedStudentsSet(*it);
 		assert(ss);
 		if(ss->type==STUDENTS_SUBGROUP){
 			int tmp;
-			for(tmp=0; tmp<=r.nInternalSubgroups; tmp++)
+			/*for(tmp=0; tmp<r.nInternalSubgroups; tmp++)
 				if(r.internalSubgroupsList[tmp]->name == ss->name)
-					break;
+					break;*/
+			tmp=((StudentsSubgroup*)ss)->indexInInternalSubgroupsList;
+			assert(tmp>=0);
 			assert(tmp<r.nInternalSubgroups);
-			assert(this->nSubgroups<MAX_SUBGROUPS_PER_ACTIVITY);
+			//assert(this->nSubgroups<MAX_SUBGROUPS_PER_ACTIVITY);
 			
 			bool duplicate=false;
-			for(int j=0; j<this->nSubgroups; j++)
-				if(this->subgroups[j]==tmp)
+			if(this->iSubgroupsList.contains(tmp))
+			//for(int j=0; j<this->nSubgroups; j++)
+			//	if(this->subgroups[j]==tmp)
 					duplicate=true;
 			if(duplicate){
 				QString s;
@@ -211,22 +217,26 @@ void Activity::computeInternalStructure(Rules& r)
 				cout<<qPrintable(s)<<endl;
 			}
 			else
-				this->subgroups[this->nSubgroups++]=tmp;
+				this->iSubgroupsList.append(tmp);
+				//this->subgroups[this->nSubgroups++]=tmp;
 		}
 		else if(ss->type==STUDENTS_GROUP){
 			StudentsGroup* stg=(StudentsGroup*)ss;
 			for(int k=0; k<stg->subgroupsList.size(); k++){
 				StudentsSubgroup* sts=stg->subgroupsList[k];
 				int tmp;
-				for(tmp=0; tmp<=r.nInternalSubgroups; tmp++)
+				/*for(tmp=0; tmp<r.nInternalSubgroups; tmp++)
 					if(r.internalSubgroupsList[tmp]->name == sts->name)
-						break;
+						break;*/
+				tmp=sts->indexInInternalSubgroupsList;
+				assert(tmp>=0);
 				assert(tmp<r.nInternalSubgroups);
-				assert(this->nSubgroups<MAX_SUBGROUPS_PER_ACTIVITY);
+				//assert(this->nSubgroups<MAX_SUBGROUPS_PER_ACTIVITY);
 
 				bool duplicate=false;
-				for(int j=0; j<this->nSubgroups; j++)
-					if(this->subgroups[j]==tmp)
+				if(this->iSubgroupsList.contains(tmp))
+				//for(int j=0; j<this->nSubgroups; j++)
+				//	if(this->subgroups[j]==tmp)
 						duplicate=true;
 				if(duplicate){
 					QString s;
@@ -236,7 +246,8 @@ void Activity::computeInternalStructure(Rules& r)
 					cout<<qPrintable(s)<<endl;
 				}
 				else
-					this->subgroups[this->nSubgroups++]=tmp;
+					//this->subgroups[this->nSubgroups++]=tmp;
+					this->iSubgroupsList.append(tmp);
 			}
 		}
 		else if(ss->type==STUDENTS_YEAR){
@@ -246,15 +257,18 @@ void Activity::computeInternalStructure(Rules& r)
 				for(int l=0; l<stg->subgroupsList.size(); l++){
 					StudentsSubgroup* sts=stg->subgroupsList[l];
 					int tmp;
-					for(tmp=0; tmp<=r.nInternalSubgroups; tmp++)
+					/*for(tmp=0; tmp<r.nInternalSubgroups; tmp++)
 						if(r.internalSubgroupsList[tmp]->name == sts->name)
-							break;
+							break;*/
+					tmp=sts->indexInInternalSubgroupsList;
+					assert(tmp>=0);
 					assert(tmp<r.nInternalSubgroups);
-					assert(this->nSubgroups<MAX_SUBGROUPS_PER_ACTIVITY);
+					//assert(this->nSubgroups<MAX_SUBGROUPS_PER_ACTIVITY);
 
 					bool duplicate=false;
-					for(int j=0; j<this->nSubgroups; j++)
-						if(this->subgroups[j]==tmp)
+					if(this->iSubgroupsList.contains(tmp))
+					//for(int j=0; j<this->nSubgroups; j++)
+					//	if(this->subgroups[j]==tmp)
 							duplicate=true;
 					if(duplicate){
 						QString s;
@@ -264,7 +278,8 @@ void Activity::computeInternalStructure(Rules& r)
 						cout<<qPrintable(s)<<endl;
 					}
 					else{
-						this->subgroups[this->nSubgroups++]=tmp;
+						//this->subgroups[this->nSubgroups++]=tmp;
+						this->iSubgroupsList.append(tmp);
 					}
 				}
 			}
@@ -283,7 +298,7 @@ QString Activity::getXmlDescription(Rules& r)
 	for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++)
 		s+="	<Teacher>" + protect(*it) + "</Teacher>\n";
 	s+="	<Subject>"+protect(this->subjectName)+"</Subject>\n";
-	s+="	<Subject_Tag>"+protect(this->subjectTagName)+"</Subject_Tag>\n";
+	s+="	<Activity_Tag>"+protect(this->activityTagName)+"</Activity_Tag>\n";
 
 	s+="	<Duration>"+QString::number(this->duration)+"</Duration>\n";
 	s+="	<Total_Duration>"+QString::number(this->totalDuration)+"</Total_Duration>\n";
@@ -312,51 +327,214 @@ QString Activity::getXmlDescription(Rules& r)
 
 QString Activity::getDescription(Rules& r)
 {
-	if(&r==NULL){	
+	Q_UNUSED(r);
+	
+	bool _indent=false;
+	if(this->isSplit() && this->id!=this->activityGroupId)
+		_indent=true;
+		
+	QString _teachers="";
+	if(teachersNames.count()==0)
+		_teachers=QObject::tr("no teachers");
+	else{
+		bool begin=true;
+		for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++){
+			if(!begin)
+				_teachers+=",";
+				
+			_teachers += *it;
+			begin=false;
+		}
 	}
 
-	QString s;
-	if(!this->isSplit())
-		s=QObject::tr("Activity: ");
+	QString _subject=this->subjectName;
+	
+	QString _activityTag=this->activityTagName;
+
+	QString _students="";
+	if(studentsNames.count()==0)
+		_students=QObject::tr("no students");
 	else{
-		if(this->id==this->activityGroupId)
-			s="";
-		else
-			s="   ";
-		s+=QObject::tr("Activity: ");
-		//s=QObject::tr("Sub-activity: ");
+		bool begin=true;
+		for(QStringList::Iterator it=this->studentsNames.begin(); it!=this->studentsNames.end(); it++){
+			if(!begin)
+				_students+=",";
+				
+			_students += *it;
+			begin=false;
+		}
+	}
+
+	QString _id;
+	_id = QString::number(id);
+
+	QString _agid="";
+	if(this->isSplit())
+		_agid = QString::number(this->activityGroupId);
+
+	QString _duration=QString::number(this->duration);
+	
+	QString _totalDuration="";
+	if(this->isSplit())
+		_totalDuration = QString::number(this->totalDuration);
+
+	QString _active;
+	if(this->active==true)
+		_active=QObject::tr("yes");
+	else
+		_active=QObject::tr("no");
+
+	QString _nstudents="";		
+	if(this->computeNTotalStudents==false)
+		_nstudents=QString::number(this->nTotalStudents);
+
+	/////////
+	QString s="";
+	if(_indent)
+		s+="   ";
+
+	if(_activityTag!="" && this->isSplit() && _nstudents!=""){
+		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, AGId:%6, D:%7, TD:%8, A:%9, NSt:%10",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no), Number of Students")
+		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active).arg(_nstudents);
+	}
+	else if(_activityTag=="" && this->isSplit() && _nstudents!=""){
+		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, AGId:%5, D:%6, TD:%7, A:%8, NSt:%9",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no), Number of Students")
+		 .arg(_teachers).arg(_subject).arg(_students)
+		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active).arg(_nstudents);
+	}
+	else if(_activityTag!="" && !this->isSplit() && _nstudents!=""){
+		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, D:%6, A:%7, NSt:%8",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Duration, Active (yes/no), Number of Students")
+		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 .arg(_id).arg(_duration).arg(_active).arg(_nstudents);
+	}
+	else if(_activityTag=="" && !this->isSplit() && _nstudents!=""){
+		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, D:%5, A:%6, NSt:%7",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Students, Id, Duration, Active (yes/no), Number of Students")
+		 .arg(_teachers).arg(_subject).arg(_students)
+		 .arg(_id).arg(_duration).arg(_active).arg(_nstudents);
+	}
+	else if(_activityTag!="" && this->isSplit() && _nstudents==""){
+		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, AGId:%6, D:%7, TD:%8, A:%9",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no)")
+		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active);
+	}
+	else if(_activityTag=="" && this->isSplit() && _nstudents==""){
+		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, AGId:%5, D:%6, TD:%7, A:%8",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no)")
+		 .arg(_teachers).arg(_subject).arg(_students)
+		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active);
+	}
+	else if(_activityTag!="" && !this->isSplit() && _nstudents==""){
+		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, D:%6, A:%7",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Duration, Active (yes/no)")
+		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 .arg(_id).arg(_duration).arg(_active);
+	}
+	else if(_activityTag=="" && !this->isSplit() && _nstudents==""){
+		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, D:%5, A:%6",
+		 "Comment for translators (do not translate this comment):\n"
+		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
+		 "Please be careful and respect arrangement.\n"
+		 "Activity: Teacher, Subject, Students, Id, Duration, Active (yes/no)")
+		 .arg(_teachers).arg(_subject).arg(_students)
+		 .arg(_id).arg(_duration).arg(_active);
+	}	
+	else
+		assert(0);
+
+	//if there is left alignment, I do a double padding with spaces in RTL languages, just to make sure
+	if(_indent && LANGUAGE_STYLE_RIGHT_TO_LEFT==true)
+		s+="   ";
+
+
+	/*QString s="";
+	if(!this->isSplit()){
+		s=QObject::tr("Activity:");
+		s+=" ";
+	}
+	else{
+		s="";
+		if(LANGUAGE_STYLE_RIGHT_TO_LEFT==false){
+			if(this->id==this->activityGroupId)
+				s="";
+			else
+				s="   ";
+		}
+		s+=QObject::tr("Activity:");
+		s+=" ";
+	}
+	s+=QObject::tr("T:", "Initial letter from Teacher");
+	if(teachersNames.count()==0){
+		s+=" ";
+		s+=QObject::tr("no teachers,");
+		s+=", ";
 	}
-	s+=QObject::tr("T:");
-	if(teachersNames.count()==0)
-		s+=QObject::tr(" no teachers, ");
 	else
 		for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++)
 			s += *it + ", ";
-	s+=QObject::tr("S:") + this->subjectName + ", ";
+	s+=QObject::tr("S:", "Initial letter from Subject") + this->subjectName + ", ";
 	if(this->subjectTagName!="")
-		s+=QObject::tr("ST:") + this->subjectTagName + ", ";
-	s+=QObject::tr("St:");
-	if(studentsNames.count()==0)
-		s+=QObject::tr(" no students, ");
+		s+=QObject::tr("AT:", "Initial letters from Activity Tag") + this->activityTagName + ", ";
+	s+=QObject::tr("St:", "Initial letter from Students");
+	if(studentsNames.count()==0){
+		s+=" ";
+		s+=QObject::tr("no students,");
+		s+=", ";
+	}
 	else
 		for(QStringList::Iterator it=this->studentsNames.begin(); it!=this->studentsNames.end(); it++)
 			s += *it + ", ";
 
 	s += QObject::tr("Id:") + QString::number(id) + ", ";
 	if(this->isSplit())
-		s += QObject::tr("AGId:") + QString::number(this->activityGroupId) + ", ";
+		s += QObject::tr("AGId:", "Initial letters from Activity Group Id") + QString::number(this->activityGroupId) + ", ";
 
-	s+=QObject::tr("D:") + QString::number(this->duration) + ", ";
+	s+=QObject::tr("D:", "Initial letter from Duration") + QString::number(this->duration) + ", ";
 	if(this->isSplit())
-		s += QObject::tr("TD:") + QString::number(this->totalDuration) + ", ";
+		s += QObject::tr("TD:", "Initial letters from Total Duration") + QString::number(this->totalDuration) + ", ";
 
 	if(this->active==true)
-		s+=QObject::tr("A: yes")+", ";
+		s+=QObject::tr("A: yes", "Initial letter from Active");
 	else
-		s+=QObject::tr("A: no")+", ";
+		s+=QObject::tr("A: no", "Initial letter from Active");
 		
-	if(this->computeNTotalStudents==false)
-		s+=QObject::tr("NSt:")+QString::number(this->nTotalStudents);
+	if(this->computeNTotalStudents==false){
+		s+=", ";
+		s+=QObject::tr("NSt:", "Initial letters from Number of Students")+QString::number(this->nTotalStudents);
+	}
+
+	if(this->isSplit() && LANGUAGE_STYLE_RIGHT_TO_LEFT==true){
+		if(this->id==this->activityGroupId)
+			s+="";
+		else
+			s+="   ";
+	}*/
 
 	return s;
 }
@@ -364,44 +542,68 @@ QString Activity::getDescription(Rules& r)
 QString Activity::getDetailedDescription(Rules &r)
 {
 	QString s;
-	if(!this->isSplit())
-		s=QObject::tr("Activity:\n");
+	if(!this->isSplit()){
+		s=QObject::tr("Activity:");
+		s+="\n";
+	}
 	else{
 		s="";
 		/*if(this->id==this->activityGroupId)
 			s="";
 		else
 			s="   ";*/
-		s+=QObject::tr("Activity:\n");
+		s+=QObject::tr("Activity:");
+		s+="\n";
 		//s+=QObject::tr("Component of a split activity\n");
 		//s=QObject::tr("Sub-activity:\n");
 	}
-	if(teachersNames.count()==0)
-		s+=QObject::tr("No teachers for this activity\n");
+	if(teachersNames.count()==0){
+		s+=QObject::tr("No teachers for this activity");
+		s+="\n";
+	}
 	else
-		for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++)
-			s+=QObject::tr("Teacher=") + (*it) + "\n";
-	s+=QObject::tr("Subject=") + this->subjectName + "\n";
-	if(this->subjectTagName!="")
-		s+=QObject::tr("Subject tag=") + this->subjectTagName + "\n";
-	if(studentsNames.count()==0)
-		s+=QObject::tr("No students sets for this activity\n");
+		for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++){
+			s+=QObject::tr("Teacher=%1").arg(*it);
+			s+="\n";
+		}
+	s+=QObject::tr("Subject=%1").arg(this->subjectName);
+	s+="\n";
+	if(this->activityTagName!=""){
+		s+=QObject::tr("Activity tag=%1").arg(this->activityTagName);
+		s+="\n";
+	}
+	if(studentsNames.count()==0){
+		s+=QObject::tr("No students sets for this activity");
+		s+="\n";
+	}
 	else
-		for(QStringList::Iterator it=this->studentsNames.begin(); it!=this->studentsNames.end(); it++)
-			s += QObject::tr("Students=")+ (*it) + "\n";
+		for(QStringList::Iterator it=this->studentsNames.begin(); it!=this->studentsNames.end(); it++){
+			s += QObject::tr("Students=%1").arg(*it);
+			s+="\n";
+		}
 
-	s += QObject::tr("Id=") + QString::number(id) + "\n";
-	if(this->isSplit())
-		s += QObject::tr("Activity group id=") + QString::number(this->activityGroupId) + "\n";
+	s += QObject::tr("Id=%1").arg(QString::number(id));
+	s+="\n";
+	if(this->isSplit()){
+		s += QObject::tr("Activity group id=%1").arg(QString::number(this->activityGroupId));
+		s+="\n";
+	}
 
-	s+=QObject::tr("Duration=") + QString::number(this->duration) + "\n";
-	if(this->isSplit())
-		s += QObject::tr("Total duration=") + QString::number(this->totalDuration) + "\n";
+	s+=QObject::tr("Duration=%1").arg(QString::number(this->duration));
+	s+="\n";
+	if(this->isSplit()){
+		s += QObject::tr("Total duration=%1").arg(QString::number(this->totalDuration));
+		s+="\n";
+	}
 
-	if(this->active==true)
-		s+=QObject::tr("Active: yes\n");
-	else
-		s+=QObject::tr("Active: no\n");
+	if(this->active==true){
+		s+=QObject::tr("Active: yes");
+		s+="\n";
+	}
+	else{
+		s+=QObject::tr("Active: no");
+		s+="\n";
+	}
 		
 	if(this->computeNTotalStudents==true){
 		int nStud=0;
