@@ -21,18 +21,21 @@ Building::~Building()
 {
 }
 
+void Building::computeInternalStructure(Rules& r)
+{
+	Q_UNUSED(r);
+}
+
 QString Building::getDescription()
 {
-	QString s=QObject::tr("N:");
-	s+=this->name;
+	QString s=QObject::tr("N:%1", "Name").arg(this->name);
 
 	return s;
 }
 
 QString Building::getDetailedDescription()
 {
-	QString s=QObject::tr("Name=");
-	s+=this->name;
+	QString s=QObject::tr("Name=%1").arg(this->name);
 	s+="\n";
 
 	return s;
@@ -49,28 +52,26 @@ QString Building::getXmlDescription()
 
 QString Building::getDetailedDescriptionWithConstraints(Rules& r)
 {
+	Q_UNUSED(r);
+
 	QString s=this->getDetailedDescription();
 
-	s+="--------------------------------------------------\n";
+	/*s+="--------------------------------------------------\n";
 	s+=QObject::tr("Space constraints directly related to this building:");
 	s+="\n";
-	for(SpaceConstraint* c=r.spaceConstraintsList.first(); c; c=r.spaceConstraintsList.next()){
+	for(int i=0; i<r.spaceConstraintsList.size(); i++){
+		SpaceConstraint* c=r.spaceConstraintsList[i];
 		if(c->isRelatedToBuilding(this)){
 			s+="\n";
 			s+=c->getDetailedDescription(r);
 		}
 	}
-	s+="--------------------------------------------------\n";
+	s+="--------------------------------------------------\n";*/
 
 	return s;
 }
 
-int BuildingsList::compareItems(QPtrCollection::Item item1, QPtrCollection::Item item2)
+int buildingsAscending (const Building* b1, const Building* b2)
 {
-	if(((Room*)item1)->name > ((Room*)item2)->name)
-		return 1;
-	else if(((Room*)item1)->name < ((Room*)item2)->name)
-		return -1;
-	else
-		return 0;
+	return b1->name < b2->name;
 }
