@@ -13,19 +13,16 @@
 #ifndef BUILDING_H
 #define BUILDING_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 
-#include <qstring.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
+#include <QString>
+#include <QList>
+#include <QStringList>
 
 class Building;
 class Rules;
 
-class BuildingsList: public QPtrList<Building>
-{
-	int compareItems(QPtrCollection::Item, QPtrCollection::Item);
-};
+typedef QList<Building*> BuildingsList;
 
 /**
 This class represents a building
@@ -39,10 +36,14 @@ public:
 	Building();
 	~Building();
 	
+	void computeInternalStructure(Rules& r);
+	
 	QString getXmlDescription();
 	QString getDescription();
 	QString getDetailedDescription();
 	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
+int buildingsAscending(const Building* b1, const Building* b2);
+
 #endif
