@@ -23,22 +23,21 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef RULES_H
 #define RULES_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 #include "timeconstraint.h"
 #include "spaceconstraint.h"
 #include "activity.h"
 #include "studentsset.h"
 #include "teacher.h"
 #include "subject.h"
-#include "subjecttag.h"
-#include "equipment.h"
-#include "building.h"
+#include "activitytag.h"
 #include "room.h"
+#include "building.h"
 
 #include <qstring.h>
 #include <qfile.h>
 #include <qtextstream.h>
-#include <qptrvector.h>
+#include <q3ptrvector.h>
 
 /**
 This class contains the processed input (all the information regarding
@@ -95,9 +94,9 @@ public:
 	SubjectsList subjectsList;
 
 	/**
-	The list of subject tags
+	The list of activity tags
 	*/
-	SubjectTagsList subjectTagsList;
+	ActivityTagsList activityTagsList;
 
 	/**
 	The list of students (groups and subgroups included).
@@ -111,20 +110,15 @@ public:
 	ActivitiesList activitiesList;
 
 	/**
-	The list of equipments
+	The list of rooms
 	*/
-	EquipmentsList equipmentsList;
+	RoomsList roomsList;
 
 	/**
 	The list of buildings
 	*/
 	BuildingsList buildingsList;
 
-	/**
-	The list of rooms
-	*/
-	RoomsList roomsList;
-
 	/**
 	The list of time constraints
 	*/
@@ -140,14 +134,14 @@ public:
 	for some activities.
 	-1 means that this activity has no fixed day
 	*/
-	int16 fixedDay[MAX_ACTIVITIES];
+	//qint16 fixedDay[MAX_ACTIVITIES];
 	
 	/**
 	This is the array which specifies a fixed hour
 	for some activities.
 	-1 means that this activity has no fixed hour
 	*/
-	int16 fixedHour[MAX_ACTIVITIES];
+	//qint16 fixedHour[MAX_ACTIVITIES];
 	
 	/**
 	This array specifies, for each activity (1), a reference to
@@ -155,7 +149,7 @@ public:
 	as the starting day of activity 2.
 	-1 means that the activity is independent of other activities.
 	*/
-	int sameDay[MAX_ACTIVITIES];
+	//int sameDay[MAX_ACTIVITIES];
 	
 	/**
 	This array specifies, for each activity (1), a reference to
@@ -163,14 +157,14 @@ public:
 	as the starting hour of activity 2.
 	-1 means that the activity is independent of other activities.
 	*/
-	int sameHour[MAX_ACTIVITIES];
+	//int sameHour[MAX_ACTIVITIES];
 	
 	/**
 	This is the array which specifies a fixed room
 	for some activities.
 	-1 means that this activity has no fixed room
 	*/
-	int16 fixedRoom[MAX_ACTIVITIES];
+	//qint16 fixedRoom[MAX_ACTIVITIES];
 	
 	/**
 	This array specifies, for each activity (1), a reference to
@@ -178,8 +172,33 @@ public:
 	as the room of activity 2.
 	-1 means that the activity is independent of other activities.
 	*/
-	int sameRoom[MAX_ACTIVITIES];
+	//int sameRoom[MAX_ACTIVITIES];
+
+	/**
+	true if the corresponding activities share any teacher
+	or students set
+	*/
+	//bool activitiesConflicting[MAX_ACTIVITIES][MAX_ACTIVITIES];
+
+	//void computeActivitiesConflicting();
+
+	/**
+	True if the activities have same teachers (maybe in other order), same students sets,
+	and same duration. A similar activity shouldn't be swapped with another one in the backtracking
+	*/
+	//bool activitiesSimilar[MAX_ACTIVITIES][MAX_ACTIVITIES];
 	
+	//void computeActivitiesSimilar();
+
+	/**
+	True if the second activity contains at least same teachers (maybe in other order), at least the 
+	same students sets, and has at least duration as activity 1.
+	An activity which contains another shouldn't be swapped in the backtracking
+	*/
+	//bool activityContained[MAX_ACTIVITIES][MAX_ACTIVITIES];
+	
+	//void computeActivitiesContained();
+
 	//The following variables contain redundant data and are used internally
 	////////////////////////////////////////////////////////////////////////
 	int nInternalTeachers;
@@ -190,6 +209,8 @@ public:
 
 	int nInternalSubgroups;
 	StudentsSubgroup* internalSubgroupsList[MAX_TOTAL_SUBGROUPS];
+	
+	StudentsYearsList augmentedYearsList;
 
 	/**
 	Here will be only the active activities.
@@ -198,24 +219,21 @@ public:
 	*/
 	int nInternalActivities;
 	Activity internalActivitiesList[MAX_ACTIVITIES];
-
-	int nInternalEquipments;
-	Equipment* internalEquipmentsList[MAX_EQUIPMENTS];
-
-	int nInternalBuildings;
-	Building* internalBuildingsList[MAX_BUILDINGS];
+	
+	QList<int> activitiesForSubject[MAX_SUBJECTS];
 
 	int nInternalRooms;
 	Room* internalRoomsList[MAX_ROOMS];
 
+	int nInternalBuildings;
+	Building* internalBuildingsList[MAX_BUILDINGS];
+
 	int nInternalTimeConstraints;
 	TimeConstraint* internalTimeConstraintsList[MAX_TIME_CONSTRAINTS];
 
 	int nInternalSpaceConstraints;
 	SpaceConstraint* internalSpaceConstraintsList[MAX_SPACE_CONSTRAINTS];
 
-	bool roomHasEquipment[MAX_ROOMS][MAX_EQUIPMENTS];
-
 	////////////////////////////////////////////////////////////////////////
 
 	/**
@@ -249,6 +267,10 @@ public:
 	Rules();
 
 	~Rules();
+	
+	void setInstitutionName(const QString& newInstitutionName);
+	
+	void setComments(const QString& newComments);
 
 	/**
 	Adds a new teacher to the list of teachers
@@ -312,36 +334,36 @@ public:
 	void sortSubjectsAlphabetically();
 
 	/**
-	Adds a new subject tag to the list of subject tags
+	Adds a new activity tag to the list of activity tags
 	(if not already in the list).
 	Returns false/true (unsuccessful/successful).
 	*/
-	bool addSubjectTag(SubjectTag* subjectTag);
+	bool addActivityTag(ActivityTag* activityTag);
 
 	/**
-	Returns the index of this subject tag in the subjectTagsList,
+	Returns the index of this activity tag in the activityTagsList,
 	or -1 if not found.
 	*/
-	int searchSubjectTag(const QString& subjectTagName);
+	int searchActivityTag(const QString& activityTagName);
 
 	/**
-	Removes this subject tag. In the list of activities, the subject tag will 
+	Removes this activity tag. In the list of activities, the activity tag will 
 	be removed from all activities which posess it.
 	It returns false on failure.
 	If successful, returns true.
 	*/
-	bool removeSubjectTag(const QString& subjectTagName);
+	bool removeActivityTag(const QString& activityTagName);
 
 	/**
-	Modifies (renames) this subject tag and takes care of all related activities.
+	Modifies (renames) this activity tag and takes care of all related activities.
 	Returns true on success, false on failure (if not found)
 	*/
-	bool modifySubjectTag(const QString& initialSubjectTagName, const QString& finalSubjectTagName);
+	bool modifyActivityTag(const QString& initialActivityTagName, const QString& finalActivityTagName);
 
 	/**
-	A function to sort the subject tags alphabetically
+	A function to sort the activity tags alphabetically
 	*/
-	void sortSubjectTagsAlphabetically();
+	void sortActivityTagsAlphabetically();
 
 	/**
 	Returns a pointer to the structure containing this student container
@@ -349,6 +371,8 @@ public:
 	*/
 	StudentsSet* searchStudentsSet(const QString& setName);
 	
+	StudentsSet* searchAugmentedStudentsSet(const QString& setName);
+	
 	/**
 	True if the students sets contain one common subgroup.
 	This function is used in constraints isRelatedToStudentsSet
@@ -367,6 +391,8 @@ public:
 	*/
 	int searchYear(const QString& yearName);
 
+	int searchAugmentedYear(const QString& yearName);
+
 	/**
 	Modifies this students year (name, number of students) and takes care of all related 
 	activities and constraints.	Returns true on success, false on failure (if not found)
@@ -391,6 +417,8 @@ public:
 	*/
 	int searchGroup(const QString& yearName, const QString& groupName);
 
+	int searchAugmentedGroup(const QString& yearName, const QString& groupName);
+
 	/**
 	Modifies this students group (name, number of students) and takes care of all related 
 	activities and constraints.	Returns true on success, false on failure (if not found)
@@ -415,6 +443,8 @@ public:
 	*/
 	int searchSubgroup(const QString& yearName, const QString& groupName, const QString& subgroupName);
 
+	int searchAugmentedSubgroup(const QString& yearName, const QString& groupName, const QString& subgroupName);
+
 	/**
 	Modifies this students subgroup (name, number of students) and takes care of all related 
 	activities and constraints.	Returns true on success, false on failure (if not found)
@@ -438,14 +468,16 @@ public:
 		int _activityGroupId,
 		const QStringList& _teachersNames,
 		const QString& _subjectName,
-		const QString& _subjectTagName,
+		const QString& _activityTagName,
 		const QStringList& _studentsNames,
 		int _duration, /*duration, in hours*/
 		int _totalDuration,
-		int _parity, /*parity: PARITY_WEEKLY or PARITY_BIWEEKLY*/
+		//int _parity, /*parity: PARITY_WEEKLY or PARITY_FORTNIGHTLY*/
 		bool _active,
-		int _preferredDay,
-		int _preferredHour);
+		//int _preferredDay,
+		//int _preferredHour,
+		bool _computeNTotalStudents,
+		int _nTotalStudents);
 
 	/**
 	Adds a new split activity to the list of activities.
@@ -460,16 +492,20 @@ public:
 		int _activityGroupId,
 		const QStringList& _teachersNames,
 		const QString& _subjectName,
-		const QString& _subjectTagName,
+		const QString& _activityTagName,
 		const QStringList& _studentsNames,
 		int _nSplits,
 		int _totalDuration,
 		int _durations[],
-		int _parities[],
+		//int _parities[],
 		bool _active[],
 		int _minDayDistance,
-		int _preferredDays[],
-		int _preferredHours[]);
+		double _weightPercentage,
+		bool _consecutiveIfSameDay,
+		//int _preferredDays[],
+		//int _preferredHours[],
+		bool _computeNTotalStudents,
+		int _nTotalStudents);
 
 	/**
 	Removes only the activity with this id.
@@ -494,70 +530,16 @@ public:
 		int _activityGroupId, 
 		const QStringList& _teachersNames,
 		const QString& _subjectName, 
-		const QString& _subjectTagName, 
+		const QString& _activityTagName, 
 		const QStringList& _studentsNames,
-		int _nTotalStudents,
+		//int _nTotalStudents,
 	 	int _nSplits,
 		int _totalDuration,
 		int _durations[],
-		int _parities[],
-		bool _active[]);
-
-	/**
-	Adds a new equipment (already allocated).
-	Returns true on success, false for already existing equipments (same name).
-	*/
-	bool addEquipment(Equipment* eq);
-
-	/**
-	Returns -1 if not found or the index in the equipments list if found.
-	*/
-	int searchEquipment(const QString& equipmentName);
-
-	/**
-	Removes the equipment with this name.
-	Returns true on success, false on failure (not found).
-	*/
-	bool removeEquipment(const QString& equipmentName);
-	
-	/**
-	Modifies (renames) this equipment and takes care of all related constraints.
-	Returns true on success, false on failure (if not found)
-	*/
-	bool modifyEquipment(const QString& initialEquipmentName, const QString& finalEquipmentName);
-
-	/**
-	A function to sort the equipments alphabetically
-	*/
-	void sortEquipmentsAlphabetically();
-
-	/**
-	Adds a new building (already allocated).
-	Returns true on success, false for already existing building (same name).
-	*/
-	bool addBuilding(Building* eq);
-
-	/**
-	Returns -1 if not found or the index in the buildings list if found.
-	*/
-	int searchBuilding(const QString& buildingName);
-
-	/**
-	Removes the building with this name.
-	Returns true on success, false on failure (not found).
-	*/
-	bool removeBuilding(const QString& buildingName);
-	
-	/**
-	Modifies (renames) this building and takes care of all related constraints.
-	Returns true on success, false on failure (if not found)
-	*/
-	bool modifyBuilding(const QString& initialBuildingName, const QString& finalBuildingName);
-
-	/**
-	A function to sort the buildings alphabetically
-	*/
-	void sortBuildingsAlphabetically();
+		//int _parities[],
+		bool _active[],
+		bool _computeNTotalStudents,
+		int nTotalStudents);
 
 	/**
 	Adds a new room (already allocated).
@@ -579,15 +561,42 @@ public:
 	/**
 	Modifies this room and takes care of all related constraints.
 	Returns true on success, false on failure (if not found)
-	It does not alter the list of equipments.
 	*/
-	bool modifyRoom(const QString& initialRoomName, const QString& finalRoomName, const QString& type, const QString& building, int capacity);
+	bool modifyRoom(const QString& initialRoomName, const QString& finalRoomName, const QString& building, int capacity);
 
 	/**
 	A function to sort the room alphabetically, by name
 	*/
 	void sortRoomsAlphabetically();
 
+	/**
+	Adds a new building (already allocated).
+	Returns true on success, false for already existing buildings (same name).
+	*/
+	bool addBuilding(Building* rm);
+
+	/**
+	Returns -1 if not found or the index in the buildings list if found.
+	*/
+	int searchBuilding(const QString& buildingName);
+
+	/**
+	Removes the building with this name.
+	Returns true on success, false on failure (not found).
+	*/
+	bool removeBuilding(const QString& buildingName);
+	
+	/**
+	Modifies this building and takes care of all related constraints.
+	Returns true on success, false on failure (if not found)
+	*/
+	bool modifyBuilding(const QString& initialBuildingName, const QString& finalBuildingName);
+
+	/**
+	A function to sort the buildings alphabetically, by name
+	*/
+	void sortBuildingsAlphabetically();
+
 	/**
 	Adds a new time constraint (already allocated).
 	Returns true on success, false for already existing constraints.
@@ -616,12 +625,12 @@ public:
 	Reads the rules from the xml input file "filename".
 	Returns true on success, false on failure (inexistent file or wrong format)
 	*/
-	bool read(const QString& filename);
+	bool read(const QString& filename, bool logIntoCurrentDirectory=false);
 
 	/**
 	Write the rules to the xml input file "inputfile".
 	*/
-	void write(const QString& filename);
+	bool write(const QString& filename);
 	
 	int activateTeacher(const QString& teacherName);
 	
@@ -629,7 +638,7 @@ public:
 	
 	int activateSubject(const QString& subjectName);
 	
-	int activateSubjectTag(const QString& subjectTagName);
+	int activateActivityTag(const QString& activityTagName);
 
 	int deactivateTeacher(const QString& teacherName);
 	
@@ -637,7 +646,7 @@ public:
 	
 	int deactivateSubject(const QString& subjectName);
 	
-	int deactivateSubjectTag(const QString& subjectTagName);
+	int deactivateActivityTag(const QString& activityTagName);
 };
 
 #endif
