@@ -36,6 +36,11 @@ using namespace std;
 #include "rules.h"
 #include "timeconstraint.h"
 
+extern bool breakDayHour[MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
+extern bool teacherNotAvailableDayHour[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
+
+#include <QMap>
+
 
 //critical function here - must be optimized for speed
 void Solution::copy(Rules& r, Solution& c){
@@ -59,6 +64,8 @@ void Solution::copy(Rules& r, Solution& c){
 	teachersMatrixReady=c.teachersMatrixReady;
 	subgroupsMatrixReady=c.subgroupsMatrixReady;
 	roomsMatrixReady=c.roomsMatrixReady;
+	
+	nPlacedActivities=c.nPlacedActivities;
 }
 
 void Solution::init(Rules& r){
@@ -253,10 +260,20 @@ double Solution::fitness(Rules& r, QString* conflictsString){
 	this->subgroupsMatrixReady=false;
 	this->roomsMatrixReady=false;
 	
+	this->nPlacedActivities=0;
+	for(int i=0; i<r.nInternalActivities; i++)
+		if(this->times[i]!=UNALLOCATED_TIME)
+			this->nPlacedActivities++;
+		
 	for(int i=0; i<r.nInternalTimeConstraints; i++){
 		QList<QString> sl;
 		QList<double> cl;
 		this->_fitness += r.internalTimeConstraintsList[i]->fitness(*this, r, cl, sl, conflictsString);
+		
+		//if(cl.count()>0)
+		//	cout<<"cl.count()=="<<cl.count()<<endl;
+		//cout<<"conflictsString=="<<conflictsString<<endl;
+			
 		conflictsWeightList+=cl;
 		conflictsDescriptionList+=sl;
 	}	
@@ -269,11 +286,46 @@ double Solution::fitness(Rules& r, QString* conflictsString){
 	}
 		
 	this->conflictsTotal=0;
-	foreach(double cn, conflictsWeightList)
+	foreach(double cn, conflictsWeightList){
+		//cout<<"cn=="<<cn<<endl;
 		conflictsTotal+=cn;
+	}
 		
-	//sort descending according to conflicts
-	for(int i=0; i<conflictsWeightList.size(); i++)
+	//cout<<"this->_fitness=="<<this->_fitness<<", conflictsTotal=="<<conflictsTotal<<endl;
+#if 0
+	//I cannot put this test. I got situations of assert failed with 15.2 != 15.2 ??? Maybe rounding errors
+	if(this->_fitness!=conflictsTotal){
+		cout<<"this->_fitness=="<<this->_fitness<<endl;
+		cout<<"conflictsTotal=="<<conflictsTotal<<endl;
+	}
+	assert(this->_fitness==conflictsTotal);//TODO
+#endif
+		
+	//sort descending according to conflicts in O(n log n)	
+	int ttt=conflictsWeightList.count();
+		
+	QMultiMap<double, QString> map;
+	assert(conflictsWeightList.count()==conflictsDescriptionList.count());
+	for(int i=0; i<conflictsWeightList.count(); i++)
+		map.insert(conflictsWeightList.at(i), conflictsDescriptionList.at(i));
+		
+	conflictsWeightList.clear();
+	conflictsDescriptionList.clear();
+	
+	QMapIterator<double, QString> i(map);
+	while (i.hasNext()) {
+		i.next();
+		conflictsWeightList.prepend(i.key());
+		conflictsDescriptionList.prepend(i.value());
+	}
+	
+	for(int i=0; i<conflictsWeightList.count()-1; i++)
+		assert(conflictsWeightList.at(i) >= conflictsWeightList.at(i+1));
+		
+	assert(conflictsWeightList.count()==conflictsDescriptionList.count());
+	assert(conflictsWeightList.count()==ttt);
+	
+	/*for(int i=0; i<conflictsWeightList.size(); i++)
 		for(int j=0; j<i; j++)
 			if(conflictsWeightList[i]>conflictsWeightList[j]){
 				double t=conflictsWeightList[i];
@@ -283,7 +335,7 @@ double Solution::fitness(Rules& r, QString* conflictsString){
 				QString s=conflictsDescriptionList[i];
 				conflictsDescriptionList[i]=conflictsDescriptionList[j];
 				conflictsDescriptionList[j]=s;
-			}
+			}*/
 			
 	this->changedForMatrixCalculation=false;
 
@@ -291,7 +343,7 @@ double Solution::fitness(Rules& r, QString* conflictsString){
 }
 
 //critical function here - must be optimized for speed
-int Solution::getTeachersMatrix(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
+int Solution::getTeachersMatrix(Rules& r, qint8 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
 	
@@ -309,8 +361,8 @@ int Solution::getTeachersMatrix(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WE
 			int day = this->times[i] % r.nDaysPerWeek;
 			Activity* act=&r.internalActivitiesList[i];
 			for(int dd=0; dd<act->duration && hour+dd<r.nHoursPerDay; dd++)
-				for(int it=0; it<act->nTeachers; it++){
-					int tch=act->teachers[it];
+				for(int it=0; it<act->iTeachersList.count(); it++){
+					int tch=act->iTeachersList.at(it);
 					int tmp=a[tch][day][hour+dd];
 					/*if(act->parity==PARITY_WEEKLY){
 						conflicts += tmp<2 ? tmp : 2;
@@ -332,7 +384,7 @@ int Solution::getTeachersMatrix(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WE
 }
 
 //critical function here - must be optimized for speed
-int Solution::getSubgroupsMatrix(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
+int Solution::getSubgroupsMatrix(Rules& r, qint8 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
 	
@@ -350,8 +402,8 @@ int Solution::getSubgroupsMatrix(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX_DAY
 			int day=this->times[i]%r.nDaysPerWeek;
 			Activity* act = &r.internalActivitiesList[i];
 			for(int dd=0; dd < act->duration && hour+dd < r.nHoursPerDay; dd++)
-				for(int isg=0; isg < act->nSubgroups; isg++){ //isg => index subgroup
-					int sg = act->subgroups[isg]; //sg => subgroup
+				for(int isg=0; isg < act->iSubgroupsList.count(); isg++){ //isg => index subgroup
+					int sg = act->iSubgroupsList.at(isg); //sg => subgroup
 					int tmp=a[sg][day][hour+dd];
 					/*if(act->parity == PARITY_WEEKLY){
 						conflicts += tmp<2 ? tmp : 2;
@@ -374,12 +426,13 @@ int Solution::getSubgroupsMatrix(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX_DAY
 
 //The following 2 functions (GetTeachersTimetable & GetSubgroupsTimetable)
 //are very similar to the above 2 ones (GetTeachersMatrix & GetSubgroupsMatrix)
-void Solution::getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
+//void Solution::getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
+void Solution::getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY], QList<qint16> b[TEACHERS_FREE_PERIODS_N_CATEGORIES][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
 	//assert(HFitness()==0); //This is only for perfect solutions, that do not have any non-satisfied hard constrains
 
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
-
+	
 	int i, j, k;
 	for(i=0; i<r.nInternalTeachers; i++)
 		for(j=0; j<r.nDaysPerWeek; j++)
@@ -393,9 +446,10 @@ void Solution::getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PE
 			act=&r.internalActivitiesList[i];
 			int hour=this->times[i]/r.nDaysPerWeek;
 			int day=this->times[i]%r.nDaysPerWeek;
-			for(int dd=0; dd < act->duration && hour+dd < r.nHoursPerDay; dd++)
-				for(int ti=0; ti<act->nTeachers; ti++){
-					int tch = act->teachers[ti]; //teacher index
+			for(int dd=0; dd < act->duration; dd++){
+				assert(hour+dd<r.nHoursPerDay);
+				for(int ti=0; ti<act->iTeachersList.count(); ti++){
+					int tch = act->iTeachersList.at(ti); //teacher index
 					/*if(a1[tch][day][hour+dd]==UNALLOCATED_ACTIVITY)
 						a1[tch][day][hour+dd]=i;
 					else
@@ -403,7 +457,103 @@ void Solution::getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PE
 					assert(a[tch][day][hour+dd]==UNALLOCATED_ACTIVITY);
 					a[tch][day][hour+dd]=i;
 				}
+			}
 		}
+
+	//Prepare teachers free periods timetable.
+	//Code contributed by Volker Dirr (http://timetabling.de/) BEGIN
+	int d,h,tch;
+	for(d=0; d<r.nDaysPerWeek; d++){
+		for(h=0; h<r.nHoursPerDay; h++){
+			for(int tfp=0; tfp<TEACHERS_FREE_PERIODS_N_CATEGORIES; tfp++){
+				b[tfp][d][h].clear();
+			}
+		}
+	}
+	for(tch=0; tch<r.nInternalTeachers; tch++){
+		for(d=0; d<r.nDaysPerWeek; d++){
+			int firstPeriod=-1;
+			int lastPeriod=-1;
+			for(h=0; h<r.nHoursPerDay; h++){
+				if(a[tch][d][h]!=UNALLOCATED_ACTIVITY){
+					if(firstPeriod==-1)
+						firstPeriod=h;
+					lastPeriod=h;
+				}
+			}
+			if(firstPeriod==-1){
+				for(h=0; h<r.nHoursPerDay; h++){
+					b[TEACHER_HAS_A_FREE_DAY][d][h]<<tch;
+				}
+			} else {
+				for(h=0; h<firstPeriod; h++){
+					if(firstPeriod-h==1){
+						b[TEACHER_MUST_COME_EARLIER][d][h]<<tch;
+					}
+					else {
+						b[TEACHER_MUST_COME_MUCH_EARLIER][d][h]<<tch;
+					}
+				}
+				for(; h<lastPeriod+1; h++){
+					if(a[tch][d][h]==UNALLOCATED_ACTIVITY){
+						if(a[tch][d][h+1]==UNALLOCATED_ACTIVITY){
+							if(a[tch][d][h-1]==UNALLOCATED_ACTIVITY){
+								b[TEACHER_HAS_BIG_GAP][d][h]<<tch;
+							} else {
+								b[TEACHER_HAS_BORDER_GAP][d][h]<<tch;
+							}
+						} else {
+							if(a[tch][d][h-1]==UNALLOCATED_ACTIVITY){
+								b[TEACHER_HAS_BORDER_GAP][d][h]<<tch;
+							} else {
+								b[TEACHER_HAS_SINGLE_GAP][d][h]<<tch;
+							}
+						}
+					}
+				}
+				for(; h<r.nHoursPerDay; h++){
+					if(lastPeriod-h==-1){
+						b[TEACHER_MUST_STAY_LONGER][d][h]<<tch;
+					}
+					else {
+						b[TEACHER_MUST_STAY_MUCH_LONGER][d][h]<<tch;
+					}
+				}
+			}
+		}
+	}
+	//care about not available teacher and breaks
+	for(tch=0; tch<r.nInternalTeachers; tch++){
+		for(d=0; d<r.nDaysPerWeek; d++){
+			for(h=0; h<r.nHoursPerDay; h++){
+				if(teacherNotAvailableDayHour[tch][d][h]==true || breakDayHour[d][h]==true){
+					int removed=0;
+					for(int tfp=0; tfp<TEACHER_IS_NOT_AVAILABLE; tfp++){
+						if(b[tfp][d][h].contains(tch)){
+							removed+=b[tfp][d][h].removeAll(tch);
+							if(breakDayHour[d][h]==false)
+								b[TEACHER_IS_NOT_AVAILABLE][d][h]<<tch;
+						}
+					}
+					assert(removed==1);
+				}
+			}
+		}
+	}
+	//END of Code contributed by Volker Dirr (http://timetabling.de/) END
+	bool visited[MAX_TEACHERS];
+	for(d=0; d<r.nDaysPerWeek; d++){
+		for(h=0; h<r.nHoursPerDay; h++){
+			for(tch=0; tch<r.nInternalTeachers; tch++)
+				visited[tch]=false;
+			for(int tfp=0; tfp<TEACHERS_FREE_PERIODS_N_CATEGORIES; tfp++){
+				foreach(int tch, b[tfp][d][h]){
+					assert(!visited[tch]);
+					visited[tch]=true;
+				}
+			}
+		}
+	}
 }
 
 void Solution::getSubgroupsTimetable(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]){
@@ -411,7 +561,7 @@ void Solution::getSubgroupsTimetable(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX
 
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
-
+	
 	int i, j, k;
 	for(i=0; i<r.nInternalSubgroups; i++)
 		for(j=0; j<r.nDaysPerWeek; j++)
@@ -425,9 +575,11 @@ void Solution::getSubgroupsTimetable(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX
 			act=&r.internalActivitiesList[i];
 			int hour=this->times[i]/r.nDaysPerWeek;
 			int day=this->times[i]%r.nDaysPerWeek;
-			for(int dd=0; dd < act->duration && hour+dd < r.nHoursPerDay; dd++){
-				for(int isg=0; isg < act->nSubgroups; isg++){ //isg -> index subgroup
-					int sg = act->subgroups[isg]; //sg -> subgroup
+			for(int dd=0; dd < act->duration; dd++){
+				assert(hour+dd<r.nHoursPerDay);
+			
+				for(int isg=0; isg < act->iSubgroupsList.count(); isg++){ //isg -> index subgroup
+					int sg = act->iSubgroupsList.at(isg); //sg -> subgroup
 					/*if(a1[sg][day][hour+dd]==UNALLOCATED_ACTIVITY)
 						a1[sg][day][hour+dd]=i;
 					else
@@ -441,7 +593,7 @@ void Solution::getSubgroupsTimetable(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX
 
 int Solution::getRoomsMatrix(
 	Rules& r, 
-	qint16 a[MAX_ROOMS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY])
+	qint8 a[MAX_ROOMS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY])
 {
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
@@ -490,7 +642,7 @@ void Solution::getRoomsTimetable(
 {
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
-
+	
 	int i, j, k;
 	for(i=0; i<r.nInternalRooms; i++)
 		for(j=0; j<r.nDaysPerWeek; j++)
@@ -507,7 +659,9 @@ void Solution::getRoomsTimetable(
 		//int day=days[i];
 		//int hour=hours[i];
 		if(room!=UNALLOCATED_SPACE && room!=UNSPECIFIED_ROOM && day!=UNALLOCATED_TIME && hour!=UNALLOCATED_TIME){
-			for(int dd=0; dd < act->duration && hour+dd < r.nHoursPerDay; dd++){
+			for(int dd=0; dd < act->duration; dd++){
+				assert(hour+dd<r.nHoursPerDay);
+			
 				/*if(a1[room][day][hour+dd]==UNALLOCATED_ACTIVITY)
 					a1[room][day][hour+dd]=i;
 				else
@@ -518,3 +672,69 @@ void Solution::getRoomsTimetable(
 		}
 	}
 }
+
+void Solution::getSubgroupsBuildingsTimetable(Rules& r, qint8 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY])
+{
+	assert(r.initialized);
+	assert(r.internalStructureComputed);
+	
+	int i, j, k;
+	for(i=0; i<r.nInternalSubgroups; i++)
+		for(j=0; j<r.nDaysPerWeek; j++)
+			for(k=0; k<r.nHoursPerDay; k++)
+				a[i][j][k]=-1;
+
+	Activity *act;
+	for(i=0; i<r.nInternalActivities; i++)
+		if(this->times[i]!=UNALLOCATED_TIME) {
+			act=&r.internalActivitiesList[i];
+			int hour=this->times[i]/r.nDaysPerWeek;
+			int day=this->times[i]%r.nDaysPerWeek;
+			for(int dd=0; dd < act->duration; dd++){
+				assert(hour+dd<r.nHoursPerDay);
+			
+				for(int isg=0; isg < act->iSubgroupsList.count(); isg++){ //isg -> index subgroup
+					int sg = act->iSubgroupsList.at(isg); //sg -> subgroup
+					assert(a[sg][day][hour+dd]==-1);
+
+					if(this->rooms[i]!=UNSPECIFIED_ROOM && this->rooms[i]!=UNALLOCATED_SPACE){
+						assert(this->rooms[i]>=0 && this->rooms[i]<r.nInternalRooms);
+						a[sg][day][hour+dd]=r.internalRoomsList[this->rooms[i]]->buildingIndex;
+					}
+				}
+			}
+		}
+}
+
+void Solution::getTeachersBuildingsTimetable(Rules& r, qint8 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY])
+{
+	assert(r.initialized);
+	assert(r.internalStructureComputed);
+	
+	int i, j, k;
+	for(i=0; i<r.nInternalTeachers; i++)
+		for(j=0; j<r.nDaysPerWeek; j++)
+			for(k=0; k<r.nHoursPerDay; k++)
+				a[i][j][k]=-1;
+
+	Activity *act;
+	for(i=0; i<r.nInternalActivities; i++) 
+		if(this->times[i]!=UNALLOCATED_TIME) {
+			act=&r.internalActivitiesList[i];
+			int hour=this->times[i]/r.nDaysPerWeek;
+			int day=this->times[i]%r.nDaysPerWeek;
+			for(int dd=0; dd < act->duration; dd++){
+				assert(hour+dd<r.nHoursPerDay);
+				for(int ti=0; ti<act->iTeachersList.count(); ti++){
+					int tch = act->iTeachersList.at(ti); //teacher index
+					assert(a[tch][day][hour+dd]==-1);
+
+					if(this->rooms[i]!=UNSPECIFIED_ROOM && this->rooms[i]!=UNALLOCATED_SPACE){
+						assert(this->rooms[i]>=0 && this->rooms[i]<r.nInternalRooms);
+						a[tch][day][hour+dd]=r.internalRoomsList[this->rooms[i]]->buildingIndex;
+					}
+
+				}
+			}
+		}
+}
