@@ -48,6 +48,8 @@ public:
 	bool teachersMatrixReady;
 	bool subgroupsMatrixReady;
 	bool roomsMatrixReady;
+	
+	int nPlacedActivities;
 
 	/*
 	You will need to set this to true if altering the times array values.
@@ -142,7 +144,8 @@ public:
 	matrix keeps the activity scheduled for the second week.
 	The arrays a1 and a2 will contain the index of the activity in the rules.
 	*/
-	void getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	void getTeachersTimetable(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY], QList<qint16> b[TEACHERS_FREE_PERIODS_N_CATEGORIES][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	//return value is the number of conflicts, must be 0
 
 	/**
 	OLD COMMENT BELOW, now FET has no fortnightly activities, 
@@ -159,6 +162,7 @@ public:
 	The arrays a1 and a2 will contain the index of the activity in the rules.
 	*/
 	void getSubgroupsTimetable(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	//return value is the number of conflicts, must be 0
 
 	/**
 	OLD COMMENT BELOW, now FET has no fortnightly activities, 
@@ -176,7 +180,7 @@ public:
 	Return value: the number of subgroups exhaustions (sum of values which are
 	over 2).
 	*/
-	int getSubgroupsMatrix(Rules& r, qint16 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	int getSubgroupsMatrix(Rules& r, qint8 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
 
 	/**
 	OLD COMMENT BELOW, now FET has no fortnightly activities, 
@@ -194,12 +198,15 @@ public:
 	Return value: the number of teachers exhaustions (sum of values which are
 	over 2).
 	*/
-	int getTeachersMatrix(Rules& r, qint16 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	int getTeachersMatrix(Rules& r, qint8 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
 
-	int getRoomsMatrix(Rules& r, qint16 a[MAX_ROOMS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	int getRoomsMatrix(Rules& r, qint8 a[MAX_ROOMS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
 
 	void getRoomsTimetable(Rules& r, qint16 a[MAX_ROOMS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
-
+	//return value is the number of conflicts, must be 0
+	
+	void getTeachersBuildingsTimetable(Rules& r, qint8 a[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
+	void getSubgroupsBuildingsTimetable(Rules& r, qint8 a[MAX_TOTAL_SUBGROUPS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY]);
 };
 
 #endif
