@@ -13,18 +13,15 @@
 #ifndef TEACHER_H
 #define TEACHER_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 
 #include <qstring.h>
-#include <qptrlist.h>
+#include <q3ptrlist.h>
 
 class Teacher;
 class Rules;
 
-class TeachersList: public QPtrList<Teacher>
-{
-	int compareItems(QPtrCollection::Item,QPtrCollection::Item);
-};
+typedef QList<Teacher*> TeachersList;
 
 /**
 @author Liviu Lalescu
@@ -32,6 +29,8 @@ class TeachersList: public QPtrList<Teacher>
 class Teacher
 {
 public:
+	QList<qint16> activitiesForTeacher;
+
 	QString name;
 
 	Teacher();
@@ -42,4 +41,6 @@ public:
 	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
+int teachersAscending(const Teacher* t1, const Teacher* t2);
+
 #endif
