@@ -46,7 +46,7 @@ public:
 	void updateStudentsListBox();
 	void updateTeachersListBox();
 	void updateSubjectsComboBox();
-	void updateSubjectTagsComboBox();
+	void updateActivityTagsComboBox();
 	void updatePreferredDaysComboBox();
 	void updatePreferredHoursComboBox();
 
@@ -55,7 +55,7 @@ public:
 	void addStudents();
 	void removeStudents();
 	void subjectChanged(const QString& dummy);
-	void subjectTagChanged(const QString& dummy);
+	void activityTagChanged(const QString& dummy);
 	void hourChanged();
 	void dayChanged();
 	void parityChanged();
