@@ -1,8 +1,8 @@
 /***************************************************************************
                           addbuildingform.cpp  -  description
                              -------------------
-    begin                : July 9, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : Feb 11 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -18,9 +18,22 @@
 #include "addbuildingform.h"
 
 #include <qlineedit.h>
+#include <q3combobox.h>
+
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
+#include <QTextEdit>
 
 AddBuildingForm::AddBuildingForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
 }
 
 AddBuildingForm::~AddBuildingForm()
@@ -36,7 +49,7 @@ void AddBuildingForm::addBuilding()
 	Building* bu=new Building();
 	bu->name=nameLineEdit->text();
 	if(!gt.rules.addBuilding(bu)){
-		QMessageBox::information(this, QObject::tr("Building insertion dialog"),
+		QMessageBox::information(this, QObject::tr("Room insertion dialog"),
 			QObject::tr("Could not insert item. Must be a duplicate"));
 		delete bu;
 	}
