@@ -25,8 +25,8 @@
 
 #include <QDesktopWidget>
 
-#define YES	(QObject::tr("Yes"))
-#define NO	(QObject::tr("No"))
+#define YES	(QObject::tr("Allowed", "Please keep translation short"))
+#define NO	(QObject::tr("Not allowed", "Please keep translation short"))
 
 AddConstraintActivitiesPreferredTimesForm::AddConstraintActivitiesPreferredTimesForm()
 {
@@ -40,7 +40,7 @@ AddConstraintActivitiesPreferredTimesForm::AddConstraintActivitiesPreferredTimes
 	updateTeachersComboBox();
 	updateStudentsComboBox();
 	updateSubjectsComboBox();
-	updateSubjectTagsComboBox();
+	updateActivityTagsComboBox();
 
 	preferredTimesTable->setNumRows(gt.rules.nHoursPerDay);
 	preferredTimesTable->setNumCols(gt.rules.nDaysPerWeek);
@@ -54,7 +54,7 @@ AddConstraintActivitiesPreferredTimesForm::AddConstraintActivitiesPreferredTimes
 
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
-			preferredTimesTable->setText(i, j, NO);
+			preferredTimesTable->setText(i, j, YES);
 }
 
 AddConstraintActivitiesPreferredTimesForm::~AddConstraintActivitiesPreferredTimesForm()
@@ -63,8 +63,10 @@ AddConstraintActivitiesPreferredTimesForm::~AddConstraintActivitiesPreferredTime
 
 void AddConstraintActivitiesPreferredTimesForm::tableClicked(int row, int col, int button, const QPoint& mousePos)
 {
-	if(&button!=NULL && &mousePos!=NULL)
-		; //to avoid "unused parameter" compiler warning
+	Q_UNUSED(button);
+	Q_UNUSED(mousePos);
+	//if(&button!=NULL && &mousePos!=NULL)
+	//	; //to avoid "unused parameter" compiler warning
 
 	//row--; col--;
 	if(row>=0 && row<gt.rules.nHoursPerDay && col>=0 && col<gt.rules.nDaysPerWeek){
@@ -114,12 +116,12 @@ void AddConstraintActivitiesPreferredTimesForm::updateSubjectsComboBox(){
 	}
 }
 
-void AddConstraintActivitiesPreferredTimesForm::updateSubjectTagsComboBox(){
-	subjectTagsComboBox->clear();
-	subjectTagsComboBox->insertItem("");
-	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
-		SubjectTag* s=gt.rules.subjectTagsList[i];
-		subjectTagsComboBox->insertItem(s->name);
+void AddConstraintActivitiesPreferredTimesForm::updateActivityTagsComboBox(){
+	activityTagsComboBox->clear();
+	activityTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
+		ActivityTag* s=gt.rules.activityTagsList[i];
+		activityTagsComboBox->insertItem(s->name);
 	}
 }
 
@@ -152,14 +154,56 @@ void AddConstraintActivitiesPreferredTimesForm::addConstraint()
 	if(subject!="")
 		assert(gt.rules.searchSubject(subject)>=0);
 		
-	QString subjectTag=subjectTagsComboBox->currentText();
-	if(subjectTag!="")
-		assert(gt.rules.searchSubjectTag(subjectTag)>=0);
+	QString activityTag=activityTagsComboBox->currentText();
+	if(activityTag!="")
+		assert(gt.rules.searchActivityTag(activityTag)>=0);
 		
-	if(teacher=="" && students=="" && subject=="" && subjectTag==""){
+	if(teacher=="" && students=="" && subject=="" && activityTag==""){
 		int t=QMessageBox::question(this, tr("FET question"),
-		 tr("Are you sure you want to add this constraint for all activities?"
-		 " (no teacher, students, subject or subject tag specified)"),
+		 tr("You specified all the activities. This might be a small problem: if you specify"
+		  " a not allowed slot between two allowed slots, this not allowed slot will"
+		  " be counted as a gap in the teachers' and students' timetable.\n\n"
+		  " The best practice would be to use constraint break times.\n\n"
+		  " If you need weight under 100%, then you can use this constraint, but be careful"
+		  " not to obtain an impossible timetable (if your teachers/students are constrained on gaps"
+		  " or early gaps and if you leave a not allowed slot between 2 allowed slots or"
+		  " a not allowed slot early in the day and more allowed slots after it,"
+		  " this possible gap might be counted in teachers' and students' timetable)")
+		  +"\n\n"+tr("Do you want to add current constraint?"),
+		 QMessageBox::Yes, QMessageBox::Cancel);
+						 
+		if(t==QMessageBox::Cancel)
+				return;
+	}
+
+	if(teacher!="" && students=="" && subject=="" && activityTag==""){
+		int t=QMessageBox::question(this, tr("FET question"),
+		 tr("You specified only the teacher. This might be a small problem: if you specify"
+		  " a not allowed slot between two allowed slots, this not allowed slot will"
+		  " be counted as a gap in the teacher's timetable.\n\n"
+		  " The best practice would be to use constraint teacher not available times.\n\n"
+		  " If you need weight under 100%, then you can use this constraint, but be careful"
+		  " not to obtain an impossible timetable (if your teacher is constrained on gaps"
+		  " and if you leave a not allowed slot between 2 allowed slots, this possible"
+		  " gap might be counted in teacher's timetable)")
+		  +"\n\n"+tr("Do you want to add current constraint?"),
+		 QMessageBox::Yes, QMessageBox::Cancel);
+						 
+		if(t==QMessageBox::Cancel)
+				return;
+	}
+	if(teacher=="" && students!="" && subject=="" && activityTag==""){
+		int t=QMessageBox::question(this, tr("FET question"),
+		 tr("You specified only the students set. This might be a small problem: if you specify"
+		  " a not allowed slot between two allowed slots (or a not allowed slot before allowed slots),"
+		  " this not allowed slot will"
+		  " be counted as a gap (or early gap) in the students' timetable.\n\n"
+		  " The best practice would be to use constraint students set not available times.\n\n"
+		  " If you need weight under 100%, then you can use this constraint, but be careful"
+		  " not to obtain an impossible timetable (if your students set is constrained on gaps or early gaps"
+		  " and if you leave a not allowed slot between 2 allowed slots (or a not allowed slot before allowed slots), this possible"
+		  " gap might be counted in students' timetable)")
+		  +"\n\n"+tr("Do you want to add current constraint?"),
 		 QMessageBox::Yes, QMessageBox::Cancel);
 						 
 		if(t==QMessageBox::Cancel)
@@ -197,7 +241,7 @@ void AddConstraintActivitiesPreferredTimesForm::addConstraint()
 				return;
 	}
 
-	ctr=new ConstraintActivitiesPreferredTimes(weight, /*compulsory,*/ teacher, students, subject, subjectTag, n, days, hours);
+	ctr=new ConstraintActivitiesPreferredTimes(weight, /*compulsory,*/ teacher, students, subject, activityTag, n, days, hours);
 
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	if(tmp2){
