@@ -19,21 +19,22 @@
 #define ADDCONSTRAINTACTIVITIESSAMESTARTINGTIMEFORM_H
 
 #include "addconstraintactivitiessamestartingtimeform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
+
+#include <QList>
 
 class AddConstraintActivitiesSameStartingTimeForm : public AddConstraintActivitiesSameStartingTimeForm_template  {
 public:
@@ -55,9 +56,9 @@ public:
 	
 private:
 	//the id's of the activities listed in the activities list
-	QValueList<int> activitiesList;
+	QList<int> activitiesList;
 	//the id-s of the activities listed in the list of simultaneous activities
-	QValueList<int> simultaneousActivitiesList;
+	QList<int> simultaneousActivitiesList;
 };
 
 #endif
