@@ -19,20 +19,20 @@
 #define ADDCONSTRAINTACTIVITYPREFERREDROOMFORM_H
 
 #include "addconstraintactivitypreferredroomform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 
 class AddConstraintActivityPreferredRoomForm : public AddConstraintActivityPreferredRoomForm_template  {
 public:
@@ -43,6 +43,13 @@ public:
 	void updateRoomsComboBox();
 
 	void addConstraint();
+
+	bool filterOk(Activity* a);
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the activities combo
+	QList<int> activitiesList;
 };
 
 #endif
