@@ -19,21 +19,21 @@
 #define ADDCONSTRAINTACTIVITYPREFERREDROOMSFORM_H
 
 #include "addconstraintactivitypreferredroomsform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
+#include <q3valuelist.h>
 
 class AddConstraintActivityPreferredRoomsForm : public AddConstraintActivityPreferredRoomsForm_template  {
 public:
@@ -41,11 +41,19 @@ public:
 	~AddConstraintActivityPreferredRoomsForm();
 
 	void updateRoomsListBox();
+	void updateActivitiesComboBox();	
 	
 	void addRoom();
 	void removeRoom();
 
 	void addConstraint();
+
+	bool filterOk(Activity* a);
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the activities combo
+	QList<int> activitiesList;
 };
 
 #endif
