@@ -22,10 +22,55 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
 #define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
 
 AddConstraintActivityPreferredTimeForm::AddConstraintActivityPreferredTimeForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
+	teachersComboBox->insertItem("");
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
+		teachersComboBox->insertItem(tch->name);
+	}
+	teachersComboBox->setCurrentItem(0);
+
+	subjectsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectsList.size(); i++){
+		Subject* sb=gt.rules.subjectsList[i];
+		subjectsComboBox->insertItem(sb->name);
+	}
+	subjectsComboBox->setCurrentItem(0);
+
+	activityTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
+		ActivityTag* st=gt.rules.activityTagsList[i];
+		activityTagsComboBox->insertItem(st->name);
+	}
+	activityTagsComboBox->setCurrentItem(0);
+
+	studentsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
+		studentsComboBox->insertItem(sty->name);
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
+			studentsComboBox->insertItem(stg->name);
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
+		}
+	}
+	studentsComboBox->setCurrentItem(0);
+	
 	updatePeriodGroupBox();
 	updateActivitiesComboBox();
 }
@@ -34,14 +79,71 @@ AddConstraintActivityPreferredTimeForm::~AddConstraintActivityPreferredTimeForm(
 {
 }
 
+bool AddConstraintActivityPreferredTimeForm::filterOk(Activity* act)
+{
+	QString tn=teachersComboBox->currentText();
+	QString stn=studentsComboBox->currentText();
+	QString sbn=subjectsComboBox->currentText();
+	QString sbtn=activityTagsComboBox->currentText();
+	int ok=true;
+
+	//teacher
+	if(tn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+			if(*it == tn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+
+	//subject
+	if(sbn!="" && sbn!=act->subjectName)
+		ok=false;
+		
+	//activity tag
+	if(sbtn!="" && sbtn!=act->activityTagName)
+		ok=false;
+		
+	//students
+	if(stn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+			if(*it == stn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+	
+	return ok;
+}
+
+
 void AddConstraintActivityPreferredTimeForm::updateActivitiesComboBox(){
 	activitiesComboBox->clear();
-	for(Activity* act=gt.rules.activitiesList.first(); act; act=gt.rules.activitiesList.next())
-		activitiesComboBox->insertItem(act->getDescription(gt.rules));
+	activitiesList.clear();
+	
+	for(int i=0; i<gt.rules.activitiesList.size(); i++){
+		Activity* act=gt.rules.activitiesList[i];
+		
+		if(filterOk(act)){
+			activitiesComboBox->insertItem(act->getDescription(gt.rules));
+			this->activitiesList.append(act->id);
+		}
+	}
 
 	constraintChanged();
 }
 
+void AddConstraintActivityPreferredTimeForm::filterChanged()
+{
+	this->updateActivitiesComboBox();
+}
+
 void AddConstraintActivityPreferredTimeForm::updatePeriodGroupBox(){
 	startHourComboBox->clear();
 	startHourComboBox->insertItem(QObject::tr("Any"));
@@ -63,24 +165,26 @@ void AddConstraintActivityPreferredTimeForm::constraintChanged()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr("Weight=%1").arg(weight);
+	s+=QObject::tr("Weight (percentage)=%1\%").arg(weight);
 	s+="\n";
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
 		compulsory=true;
 	s+=QObject::tr("Compulsory=%1").arg(yesNo(compulsory));
-	s+="\n";
+	s+="\n";*/
 
 	s+=QObject::tr("Activity preferred time");
 	s+="\n";
 	int tmp2=activitiesComboBox->currentItem();
-	if(tmp2<0 || (uint)(tmp2)>=gt.rules.activitiesList.count()){
+	assert(tmp2<activitiesList.size());
+	assert(tmp2<gt.rules.activitiesList.size());
+	if(tmp2<0){
 		s+=QObject::tr("Invalid activity");
 		s+="\n";
 	}
 	else{
-		int id=gt.rules.activitiesList.at(tmp2)->id;
+		int id=activitiesList.at(tmp2);
 		s+=QObject::tr("Activity id=%1").arg(id);
 		s+="\n";
 	}
@@ -104,6 +208,8 @@ void AddConstraintActivityPreferredTimeForm::constraintChanged()
 		s+=QObject::tr("Start hour:%1").arg(startHourComboBox->currentText());
 		s+="\n";
 	}
+	
+	currentConstraintTextEdit->setText(s);
 }
 
 void AddConstraintActivityPreferredTimeForm::addCurrentConstraint()
@@ -113,15 +219,15 @@ void AddConstraintActivityPreferredTimeForm::addCurrentConstraint()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<=0.0){
+	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+			QObject::tr("Invalid weight (percentage)"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	int day=dayComboBox->currentItem();
 	if(day<0 || day>gt.rules.nDaysPerWeek){
@@ -144,15 +250,17 @@ void AddConstraintActivityPreferredTimeForm::addCurrentConstraint()
 
 	int id;
 	int tmp2=activitiesComboBox->currentItem();
-	if(tmp2<0 || (uint)(tmp2)>=gt.rules.activitiesList.count()){
+	assert(tmp2<gt.rules.activitiesList.size());
+	assert(tmp2<activitiesList.size());
+	if(tmp2<0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid activity"));
 		return;
 	}
 	else
-		id=gt.rules.activitiesList.at(tmp2)->id;
+		id=activitiesList.at(tmp2);
 	
-	ctr=new ConstraintActivityPreferredTime(weight, compulsory, id, day-1, startHour-1);
+	ctr=new ConstraintActivityPreferredTime(weight, /*compulsory,*/ id, day-1, startHour-1);
 
 	bool tmp3=gt.rules.addTimeConstraint(ctr);
 	if(tmp3)
@@ -160,7 +268,7 @@ void AddConstraintActivityPreferredTimeForm::addCurrentConstraint()
 			QObject::tr("Constraint added"));
 	else{
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Constraint NOT added - please report error"));
+			QObject::tr("Constraint NOT added - duplicate"));
 		delete ctr;
 	}
 }
