@@ -19,19 +19,21 @@
 #define ADDCONSTRAINTACTIVITYPREFERREDTIMEFORM_H
 
 #include "addconstraintactivitypreferredtimeform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+
+#include <QList>
 
 class AddConstraintActivityPreferredTimeForm : public AddConstraintActivityPreferredTimeForm_template  {
 public:
@@ -43,6 +45,13 @@ public:
 
 	void constraintChanged();
 	void addCurrentConstraint();
+	
+	bool filterOk(Activity* a);
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the activities combo
+	QList<int> activitiesList;
 };
 
 #endif
