@@ -22,11 +22,20 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 
-#define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
+#include <QDesktopWidget>
 
 AddConstraintTeachersMaxHoursContinuouslyForm::AddConstraintTeachersMaxHoursContinuouslyForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	updateMaxHoursSpinBox();
+	
+	constraintChanged();
 }
 
 AddConstraintTeachersMaxHoursContinuouslyForm::~AddConstraintTeachersMaxHoursContinuouslyForm()
@@ -48,16 +57,16 @@ void AddConstraintTeachersMaxHoursContinuouslyForm::constraintChanged()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr(QString("Weight=%1").arg(weight));
+	s+=QObject::tr("Weight (percentage)=%1").arg(weight);
 	s+="\n";
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
 		compulsory=true;
 	s+=QObject::tr("Compulsory=%1").arg(yesNo(compulsory));
-	s+="\n";
+	s+="\n";*/
 
-	s+=QObject::tr("Teachers no more than max hours continuously");
+	s+=QObject::tr("Teachers max hours continuously");
 	s+="\n";
 
 	s+=QObject::tr("Max hours continuously=%1").arg(maxHoursSpinBox->value());
@@ -73,19 +82,24 @@ void AddConstraintTeachersMaxHoursContinuouslyForm::addCurrentConstraint()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+			QObject::tr("Invalid weight (percentage)"));
 		return;
 	}
+	/*if(weight!=100.0){
+		QMessageBox::warning(this, QObject::tr("FET information"),
+			QObject::tr("Invalid weight (percentage) - must be 100%"));
+		return;
+	}*/
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	int max_hours=maxHoursSpinBox->value();
 
-	ctr=new ConstraintTeachersMaxHoursContinuously(weight, compulsory, max_hours);
+	ctr=new ConstraintTeachersMaxHoursContinuously(weight, /*compulsory,*/ max_hours);
 
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	if(tmp2)
