@@ -45,12 +45,16 @@ AddRoomForm::AddRoomForm()
 				break;
 		if(i==typesComboBox->count())
 			typesComboBox->insertItem(rm->type);
-	}
+	}*/
 
 	buildingsComboBox->clear();
 	buildingsComboBox->insertItem("");
 	for(int i=0; i<gt.rules.buildingsList.size(); i++)
-		buildingsComboBox->insertItem(gt.rules.buildingsList.at(i)->name);*/
+		buildingsComboBox->insertItem(gt.rules.buildingsList.at(i)->name);
+		
+	capacitySpinBox->setMinValue(1);
+	capacitySpinBox->setMaxValue(MAX_ROOM_CAPACITY);
+	capacitySpinBox->setValue(MAX_ROOM_CAPACITY);
 }
 
 AddRoomForm::~AddRoomForm()
@@ -66,15 +70,15 @@ void AddRoomForm::addRoom()
 	/*if(typesComboBox->currentText().isEmpty()){
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Incorrect type"));
 		return;
-	}
+	}*/
 	if(buildingsComboBox->currentItem()<0){
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Incorrect building"));
 		return;
-	}*/
+	}
 	Room* rm=new Room();
 	rm->name=nameLineEdit->text();
 	//rm->type=typesComboBox->currentText();
-	//rm->building=buildingsComboBox->currentText();
+	rm->building=buildingsComboBox->currentText();
 	rm->capacity=capacitySpinBox->value();
 	if(!gt.rules.addRoom(rm)){
 		QMessageBox::information(this, QObject::tr("Room insertion dialog"),
@@ -100,6 +104,12 @@ void AddRoomForm::help()
 	 "special rooms needed (no need to input home rooms for teachers or students)\n\n"
 	 "It is advisable to generate the timetable without the rooms, then, if a solution is possible, to add rooms"
 	 );
+	 
+	s+="\n\n";
+	
+	s+=QObject::tr("Please note that each room can hold a single activity at a specified period. If you"
+	 " have a very large room, which can hold more activities at one time, please add more rooms,"
+	 " representing this larger room");
 	
 	//show the message in a dialog
 	QDialog* dialog=new QDialog();
