@@ -20,15 +20,15 @@
 
 #include "addstudentssubgroupform_template.h"
 
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
 
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
 #include <qspinbox.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 
 
 class AddStudentsSubgroupForm : public AddStudentsSubgroupForm_template {
