@@ -17,35 +17,43 @@
 
 #include "alltimeconstraintsform.h"
 
-#include "modifyconstraintbreakform.h"
+#include "modifyconstraintbreaktimesform.h"
 #include "modifyconstraintbasiccompulsorytimeform.h"
 
 #include "modifyconstraintactivitypreferredtimesform.h"
 #include "modifyconstraint2activitiesconsecutiveform.h"
+#include "modifyconstraint2activitiesorderedform.h"
 #include "modifyconstraintactivitiespreferredtimesform.h"
 #include "modifyconstraintactivitiessamestartingtimeform.h"
 #include "modifyconstraintactivitiessamestartinghourform.h"
+#include "modifyconstraintactivitiessamestartingdayform.h"
 #include "modifyconstraintactivitypreferredtimeform.h"
 #include "modifyconstraintactivitiesnotoverlappingform.h"
 #include "modifyconstraintminndaysbetweenactivitiesform.h"
 #include "modifyconstraintactivityendsstudentsdayform.h"
 
-#include "modifyconstraintteachernotavailableform.h"
+#include "modifyconstraintteachernotavailabletimesform.h"
 #include "modifyconstraintteachersmaxgapsperweekform.h"
 #include "modifyconstraintteachermaxgapsperweekform.h"
+#include "modifyconstraintteachersmaxgapsperdayform.h"
+#include "modifyconstraintteachermaxgapsperdayform.h"
 #include "modifyconstraintteachermaxdaysperweekform.h"
 #include "modifyconstraintteachersmaxhoursdailyform.h"
 #include "modifyconstraintteachermaxhoursdailyform.h"
+#include "modifyconstraintteachersmaxhourscontinuouslyform.h"
+#include "modifyconstraintteachermaxhourscontinuouslyform.h"
 #include "modifyconstraintteachersminhoursdailyform.h"
 #include "modifyconstraintteacherminhoursdailyform.h"
 
-#include "modifyconstraintstudentssetnotavailableform.h"
-#include "modifyconstraintstudentssetnogapsform.h"
-#include "modifyconstraintstudentsnogapsform.h"
-#include "modifyconstraintstudentsearlyform.h"
-#include "modifyconstraintstudentssetearlyform.h"
+#include "modifyconstraintstudentssetnotavailabletimesform.h"
+#include "modifyconstraintstudentssetmaxgapsperweekform.h"
+#include "modifyconstraintstudentsmaxgapsperweekform.h"
+#include "modifyconstraintstudentsearlymaxbeginningsatsecondhourform.h"
+#include "modifyconstraintstudentssetearlymaxbeginningsatsecondhourform.h"
 #include "modifyconstraintstudentssetmaxhoursdailyform.h"
 #include "modifyconstraintstudentsmaxhoursdailyform.h"
+#include "modifyconstraintstudentssetmaxhourscontinuouslyform.h"
+#include "modifyconstraintstudentsmaxhourscontinuouslyform.h"
 #include "modifyconstraintstudentssetminhoursdailyform.h"
 #include "modifyconstraintstudentsminhoursdailyform.h"
 
@@ -137,6 +145,11 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraint2ActivitiesConsecutiveForm((Constraint2ActivitiesConsecutive*)ctr);
 		form->exec();
 	}
+	else if(ctr->type==CONSTRAINT_2_ACTIVITIES_ORDERED){
+		ModifyConstraint2ActivitiesOrderedForm* form=
+		 new ModifyConstraint2ActivitiesOrderedForm((Constraint2ActivitiesOrdered*)ctr);
+		form->exec();
+	}
 	else if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_TIMES){
 		ModifyConstraintActivityPreferredTimesForm* form=
 		 new ModifyConstraintActivityPreferredTimesForm((ConstraintActivityPreferredTimes*)ctr);
@@ -157,19 +170,24 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintActivitiesSameStartingHourForm((ConstraintActivitiesSameStartingHour*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_TEACHER_NOT_AVAILABLE){
-		ModifyConstraintTeacherNotAvailableForm* form=
-		 new ModifyConstraintTeacherNotAvailableForm((ConstraintTeacherNotAvailable*)ctr);
+	else if(ctr->type==CONSTRAINT_ACTIVITIES_SAME_STARTING_DAY){
+		ModifyConstraintActivitiesSameStartingDayForm* form=
+		 new ModifyConstraintActivitiesSameStartingDayForm((ConstraintActivitiesSameStartingDay*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_SET_NOT_AVAILABLE){
-		ModifyConstraintStudentsSetNotAvailableForm* form=
-		 new ModifyConstraintStudentsSetNotAvailableForm((ConstraintStudentsSetNotAvailable*)ctr);
+	else if(ctr->type==CONSTRAINT_TEACHER_NOT_AVAILABLE_TIMES){
+		ModifyConstraintTeacherNotAvailableTimesForm* form=
+		 new ModifyConstraintTeacherNotAvailableTimesForm((ConstraintTeacherNotAvailableTimes*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_BREAK){
-		ModifyConstraintBreakForm* form=
-		 new ModifyConstraintBreakForm((ConstraintBreak*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_NOT_AVAILABLE_TIMES){
+		ModifyConstraintStudentsSetNotAvailableTimesForm* form=
+		 new ModifyConstraintStudentsSetNotAvailableTimesForm((ConstraintStudentsSetNotAvailableTimes*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_BREAK_TIMES){
+		ModifyConstraintBreakTimesForm* form=
+		 new ModifyConstraintBreakTimesForm((ConstraintBreakTimes*)ctr);
 		form->exec();
 	}
 	else if(ctr->type==CONSTRAINT_TEACHER_MAX_DAYS_PER_WEEK){
@@ -187,6 +205,16 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintTeacherMaxHoursDailyForm((ConstraintTeacherMaxHoursDaily*)ctr);
 		form->exec();
 	}
+	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_HOURS_CONTINUOUSLY){
+		ModifyConstraintTeachersMaxHoursContinuouslyForm* form=
+		 new ModifyConstraintTeachersMaxHoursContinuouslyForm((ConstraintTeachersMaxHoursContinuously*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_TEACHER_MAX_HOURS_CONTINUOUSLY){
+		ModifyConstraintTeacherMaxHoursContinuouslyForm* form=
+		 new ModifyConstraintTeacherMaxHoursContinuouslyForm((ConstraintTeacherMaxHoursContinuously*)ctr);
+		form->exec();
+	}
 	else if(ctr->type==CONSTRAINT_TEACHERS_MIN_HOURS_DAILY){
 		ModifyConstraintTeachersMinHoursDailyForm* form=
 		 new ModifyConstraintTeachersMinHoursDailyForm((ConstraintTeachersMinHoursDaily*)ctr);
@@ -207,29 +235,39 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintTeacherMaxGapsPerWeekForm((ConstraintTeacherMaxGapsPerWeek*)ctr);
 		form->exec();
 	}
+	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_GAPS_PER_DAY){
+		ModifyConstraintTeachersMaxGapsPerDayForm* form=
+		 new ModifyConstraintTeachersMaxGapsPerDayForm((ConstraintTeachersMaxGapsPerDay*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_TEACHER_MAX_GAPS_PER_DAY){
+		ModifyConstraintTeacherMaxGapsPerDayForm* form=
+		 new ModifyConstraintTeacherMaxGapsPerDayForm((ConstraintTeacherMaxGapsPerDay*)ctr);
+		form->exec();
+	}
 	else if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_TIME){
 		ModifyConstraintActivityPreferredTimeForm* form=
 		 new ModifyConstraintActivityPreferredTimeForm((ConstraintActivityPreferredTime*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_SET_NO_GAPS){
-		ModifyConstraintStudentsSetNoGapsForm* form=
-		 new ModifyConstraintStudentsSetNoGapsForm((ConstraintStudentsSetNoGaps*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MAX_GAPS_PER_WEEK){
+		ModifyConstraintStudentsSetMaxGapsPerWeekForm* form=
+		 new ModifyConstraintStudentsSetMaxGapsPerWeekForm((ConstraintStudentsSetMaxGapsPerWeek*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_NO_GAPS){
-		ModifyConstraintStudentsNoGapsForm* form=
-		 new ModifyConstraintStudentsNoGapsForm((ConstraintStudentsNoGaps*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_MAX_GAPS_PER_WEEK){
+		ModifyConstraintStudentsMaxGapsPerWeekForm* form=
+		 new ModifyConstraintStudentsMaxGapsPerWeekForm((ConstraintStudentsMaxGapsPerWeek*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_EARLY){
-		ModifyConstraintStudentsEarlyForm* form=
-		 new ModifyConstraintStudentsEarlyForm((ConstraintStudentsEarly*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_EARLY_MAX_BEGINNINGS_AT_SECOND_HOUR){
+		ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm* form=
+		 new ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm((ConstraintStudentsEarlyMaxBeginningsAtSecondHour*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_SET_EARLY){
-		ModifyConstraintStudentsSetEarlyForm* form=
-		 new ModifyConstraintStudentsSetEarlyForm((ConstraintStudentsSetEarly*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_EARLY_MAX_BEGINNINGS_AT_SECOND_HOUR){
+		ModifyConstraintStudentsSetEarlyMaxBeginningsAtSecondHourForm* form=
+		 new ModifyConstraintStudentsSetEarlyMaxBeginningsAtSecondHourForm((ConstraintStudentsSetEarlyMaxBeginningsAtSecondHour*)ctr);
 		form->exec();
 	}
 	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MAX_HOURS_DAILY){
@@ -242,6 +280,16 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintStudentsMaxHoursDailyForm((ConstraintStudentsMaxHoursDaily*)ctr);
 		form->exec();
 	}
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MAX_HOURS_CONTINUOUSLY){
+		ModifyConstraintStudentsSetMaxHoursContinuouslyForm* form=
+		 new ModifyConstraintStudentsSetMaxHoursContinuouslyForm((ConstraintStudentsSetMaxHoursContinuously*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_STUDENTS_MAX_HOURS_CONTINUOUSLY){
+		ModifyConstraintStudentsMaxHoursContinuouslyForm* form=
+		 new ModifyConstraintStudentsMaxHoursContinuouslyForm((ConstraintStudentsMaxHoursContinuously*)ctr);
+		form->exec();
+	}
 	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MIN_HOURS_DAILY){
 		ModifyConstraintStudentsSetMinHoursDailyForm* form=
 		 new ModifyConstraintStudentsSetMinHoursDailyForm((ConstraintStudentsSetMinHoursDaily*)ctr);
