@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2005
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -21,19 +21,18 @@
 class BuildingsForm : public BuildingsForm_template
 {
 public:
-	BuildingsForm();
+	BuildingsList visibleBuildingsList;
 
+	BuildingsForm();
 	~BuildingsForm();
 
 	void addBuilding();
-
 	void removeBuilding();
-
 	void modifyBuilding();
-
 	void sortBuildings();
-
 	void buildingChanged(int index);
+	void filterChanged();
+	bool filterOk(Building* bu);
 };
 
 #endif
