@@ -1,5 +1,5 @@
 /***************************************************************************
-                          constraintactivitiessamestartinghour.h  -  description
+                          constraintactivitiessamestartinghourform.h  -  description
                              -------------------
     begin                : 15 Feb 2005
     copyright            : (C) 2005 by Lalescu Liviu
@@ -19,20 +19,20 @@
 #define CONSTRAINTACTIVITIESSAMESTARTINGHOURFORM_H
 
 #include "constraintactivitiessamestartinghourform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qlistbox.h>
+#include <q3textedit.h>
+#include <q3listbox.h>
 
 class ConstraintActivitiesSameStartingHourForm : public ConstraintActivitiesSameStartingHourForm_template  {
 public:
