@@ -51,12 +51,12 @@ ConstraintActivityPreferredRoomForm::ConstraintActivityPreferredRoomForm()
 	}
 	subjectsComboBox->setCurrentItem(0);
 
-	subjectTagsComboBox->insertItem("");
-	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
-		SubjectTag* st=gt.rules.subjectTagsList[i];
-		subjectTagsComboBox->insertItem(st->name);
+	activityTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
+		ActivityTag* st=gt.rules.activityTagsList[i];
+		activityTagsComboBox->insertItem(st->name);
 	}
-	subjectTagsComboBox->setCurrentItem(0);
+	activityTagsComboBox->setCurrentItem(0);
 
 	studentsComboBox->insertItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
@@ -90,7 +90,7 @@ bool ConstraintActivityPreferredRoomForm::filterOk(SpaceConstraint* ctr)
 	
 	QString tn=teachersComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=subjectTagsComboBox->currentText();
+	QString sbtn=activityTagsComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 		
 	bool found=true;
@@ -120,8 +120,8 @@ bool ConstraintActivityPreferredRoomForm::filterOk(SpaceConstraint* ctr)
 		if(sbn!="" && sbn!=act->subjectName)
 			found=false;
 	
-		//subject tag
-		if(sbtn!="" && sbtn!=act->subjectTagName)
+		//activity tag
+		if(sbtn!="" && sbtn!=act->activityTagName)
 			found=false;
 	
 		//students
