@@ -19,22 +19,24 @@
 #define CONSTRAINTACTIVITYPREFERREDROOMFORM_H
 
 #include "constraintactivitypreferredroomform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qlistbox.h>
+#include <q3textedit.h>
+#include <q3listbox.h>
 
 class ConstraintActivityPreferredRoomForm : public ConstraintActivityPreferredRoomForm_template  {
+	Q_OBJECT
+
 public:
 	SpaceConstraintsList visibleConstraintsList;
 
