@@ -17,8 +17,20 @@
 
 #include "helpaboutform.h"
 
+#include <QDesktopWidget>
+
 HelpAboutForm::HelpAboutForm()
 {
+	setupUi(this);
+	
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+	
+	tabWidget->setCurrentIndex(0);
 }
 
 HelpAboutForm::~HelpAboutForm()
