@@ -17,8 +17,16 @@
 
 #include "helpfaqform.h"
 
+#include <QDesktopWidget>
+
 HelpFaqForm::HelpFaqForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
 }
 
 HelpFaqForm::~HelpFaqForm()
