@@ -1,8 +1,8 @@
 /***************************************************************************
                           modifyconstraint2activitiesconsecutiveform.h  -  description
                              -------------------
-    begin                : 15 Feb 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : Aug 21, 2007
+    copyright            : (C) 2007 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -19,32 +19,37 @@
 #define MODIFYCONSTRAINT2ACTIVITIESCONSECUTIVEFORM_H
 
 #include "modifyconstraint2activitiesconsecutiveform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
+#include <q3groupbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 
 class ModifyConstraint2ActivitiesConsecutiveForm : public ModifyConstraint2ActivitiesConsecutiveForm_template  {
-	Constraint2ActivitiesConsecutive* _ctr;
 public:
+	Constraint2ActivitiesConsecutive* _ctr;
+
 	ModifyConstraint2ActivitiesConsecutiveForm(Constraint2ActivitiesConsecutive* ctr);
 	~ModifyConstraint2ActivitiesConsecutiveForm();
 
-	void weightChanged();
-	void activitiesIdsTextChanged();
+	void updateActivitiesComboBox();
+
 	void constraintChanged();
-	
 	void ok();
 	void cancel();
+
+	bool filterOk(Activity* a);
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the activities combo
+	QList<int> firstActivitiesList;
+	QList<int> secondActivitiesList;
 };
 
 #endif
