@@ -21,14 +21,24 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qtable.h>
+#include <q3table.h>
+
+#include <QDesktopWidget>
 
 ModifyConstraintActivityPreferredRoomsForm::ModifyConstraintActivityPreferredRoomsForm(ConstraintActivityPreferredRooms* ctr)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	updateRoomsListBox();
 
 	int j=-1, i=0;
-	for(Activity* ac=gt.rules.activitiesList.first(); ac; ac=gt.rules.activitiesList.next()){
+	for(int k=0; k<gt.rules.activitiesList.size(); k++){
+		Activity* ac=gt.rules.activitiesList[k];
 		activitiesComboBox->insertItem(ac->getDescription(gt.rules));
 		if(ac->id==ctr->activityId){
 			assert(j==-1);
@@ -41,8 +51,8 @@ ModifyConstraintActivityPreferredRoomsForm::ModifyConstraintActivityPreferredRoo
 	
 	this->_ctr=ctr;
 	
-	weightLineEdit->setText(QString::number(ctr->weight));
-	compulsoryCheckBox->setChecked(ctr->compulsory);
+	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+//	compulsoryCheckBox->setChecked(ctr->compulsory);
 	
 	for(QStringList::Iterator it=ctr->roomsNames.begin(); it!=ctr->roomsNames.end(); it++)
 		selectedRoomsListBox->insertItem(*it);
@@ -57,8 +67,10 @@ void ModifyConstraintActivityPreferredRoomsForm::updateRoomsListBox()
 	roomsListBox->clear();
 	selectedRoomsListBox->clear();
 
-	for(Room* rm=gt.rules.roomsList.first(); rm; rm=gt.rules.roomsList.next())
+	for(int i=0; i<gt.rules.roomsList.size(); i++){
+		Room* rm=gt.rules.roomsList[i];
 		roomsListBox->insertItem(rm->name);
+	}
 }
 
 void ModifyConstraintActivityPreferredRoomsForm::ok()
@@ -66,15 +78,15 @@ void ModifyConstraintActivityPreferredRoomsForm::ok()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid weight"));
 		return;
 	}
 
-	bool compulsory=false;
+/*	bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	if(selectedRoomsListBox->count()==0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
@@ -83,12 +95,7 @@ void ModifyConstraintActivityPreferredRoomsForm::ok()
 	}
 	if(selectedRoomsListBox->count()==1){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Only one selected room"));
-		return;
-	}
-	if(selectedRoomsListBox->count()>(uint)(MAX_CONSTRAINT_ACTIVITY_PREFERRED_ROOMS)){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Please report error to the author\nMAX_CONSTRAINT_ACTIVITY_PREFERRED_ROOM must be increased (you have too many selected rooms)"));
+			QObject::tr("Only one selected room - please use constraint activity preferred room if you want a single room"));
 		return;
 	}
 	
@@ -103,8 +110,8 @@ void ModifyConstraintActivityPreferredRoomsForm::ok()
 	for(uint i=0; i<selectedRoomsListBox->count(); i++)
 		roomsList.append(selectedRoomsListBox->text(i));
 	
-	this->_ctr->weight=weight;
-	this->_ctr->compulsory=compulsory;
+	this->_ctr->weightPercentage=weight;
+//	this->_ctr->compulsory=compulsory;
 	this->_ctr->activityId=id;
 	this->_ctr->roomsNames=roomsList;
 	
