@@ -19,21 +19,21 @@
 #define MODIFYCONSTRAINTACTIVITYPREFERREDROOMSFORM_H
 
 #include "modifyconstraintactivitypreferredroomsform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
+#include <q3valuelist.h>
 
 class ModifyConstraintActivityPreferredRoomsForm : public ModifyConstraintActivityPreferredRoomsForm_template  {
 public:
