@@ -19,22 +19,24 @@
 #define MODIFYCONSTRAINTACTIVITYPREFERREDTIMESFORM_H
 
 #include "modifyconstraintactivitypreferredtimesform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 #include <qpoint.h>
 
 class ModifyConstraintActivityPreferredTimesForm : public ModifyConstraintActivityPreferredTimesForm_template  {
+	Q_OBJECT
+
 	ConstraintActivityPreferredTimes* _ctr;
 public:
 	ModifyConstraintActivityPreferredTimesForm(ConstraintActivityPreferredTimes* ctr);
@@ -46,6 +48,14 @@ public:
 	void cancel();
 	
 	void tableClicked(int, int, int, const QPoint&);
+
+	bool filterOk(Activity* a);
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the activities combo
+	QList<int> activitiesList;
+
 };
 
 #endif
