@@ -18,23 +18,40 @@
 #include "modifyroomform.h"
 
 #include <qlineedit.h>
-#include <qcombobox.h>
+#include <q3combobox.h>
 
-ModifyRoomForm::ModifyRoomForm(const QString& initialRoomName, const QString& initialRoomType, const QString& initialRoomBuilding, int initialRoomCapacity)
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
+ModifyRoomForm::ModifyRoomForm(const QString& initialRoomName, const QString& initialRoomBuilding, int initialRoomCapacity)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
+	capacitySpinBox->setMinValue(1);
+	capacitySpinBox->setMaxValue(MAX_ROOM_CAPACITY);
+	capacitySpinBox->setValue(MAX_ROOM_CAPACITY);
+
 	this->_initialRoomName=initialRoomName;
-	this->_initialRoomType=initialRoomType;
+	//this->_initialRoomType=initialRoomType;
 	this->_initialRoomBuilding=initialRoomBuilding;
 	this->_initialRoomCapacity=initialRoomCapacity;
 	capacitySpinBox->setValue(initialRoomCapacity);
+
 	nameLineEdit->setText(initialRoomName);
 	nameLineEdit->selectAll();
 	nameLineEdit->setFocus();
 	
-	typesComboBox->clear();
+	/*typesComboBox->clear();
 	typesComboBox->setDuplicatesEnabled(false);
 	int i=0, j=-1;
-	for(Room* rm=gt.rules.roomsList.first(); rm; rm=gt.rules.roomsList.next()){
+	for(int ri=0; ri<gt.rules.roomsList.size(); ri++){
+		Room* rm=gt.rules.roomsList[ri];
 		int k;
 		for(k=0; k<typesComboBox->count(); k++)
 			if(typesComboBox->text(k)==rm->type)
@@ -49,17 +66,18 @@ ModifyRoomForm::ModifyRoomForm(const QString& initialRoomName, const QString& in
 		}
 	}
 	assert(j>=0);
-	typesComboBox->setCurrentItem(j);
+	typesComboBox->setCurrentItem(j);*/
 
-	i=0;j=-1;
+	int i=0;
+	int j=-1;
 	buildingsComboBox->clear();
 	buildingsComboBox->insertItem("");
 	if(initialRoomBuilding=="")
 		j=i;
 	i++;
-	for(Building* bu=gt.rules.buildingsList.first(); bu; bu=gt.rules.buildingsList.next(), i++){
-		buildingsComboBox->insertItem(bu->name);
-		if(bu->name==initialRoomBuilding)
+	for(int k=0; k<gt.rules.buildingsList.size(); k++, i++){
+		buildingsComboBox->insertItem(gt.rules.buildingsList.at(k)->name);
+		if(gt.rules.buildingsList.at(k)->name==initialRoomBuilding)
 			j=i;
 	}
 	assert(j>=0);
@@ -81,10 +99,10 @@ void ModifyRoomForm::ok()
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Incorrect name"));
 		return;
 	}
-	if(typesComboBox->currentText().isEmpty()){
+	/*if(typesComboBox->currentText().isEmpty()){
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Incorrect type"));
 		return;
-	}
+	}*/
 	if(buildingsComboBox->currentItem()<0){
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Incorrect building"));
 		return;
@@ -94,7 +112,7 @@ void ModifyRoomForm::ok()
 		return;
 	}
 	
-	bool t=gt.rules.modifyRoom(this->_initialRoomName, nameLineEdit->text(), typesComboBox->currentText(), buildingsComboBox->currentText(), capacitySpinBox->value());
+	bool t=gt.rules.modifyRoom(this->_initialRoomName, nameLineEdit->text()/*, typesComboBox->currentText()*/, buildingsComboBox->currentText(), capacitySpinBox->value());
 	assert(t);
 	
 	this->close();
