@@ -116,7 +116,7 @@ void TimetableViewRoomsForm::updateRoomsTimetableTable(){
 			if(ai!=UNALLOCATED_ACTIVITY){
 				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
-				s += act->subjectName + " " + act->subjectTagName;
+				s += act->subjectName + " " + act->activityTagName;
 			}
 			roomsTimetableTable->setText(j, k, s);
 		}
@@ -189,6 +189,10 @@ void TimetableViewRoomsForm::lock(bool lockTime, bool lockSpace)
 	assert(rooms_schedule_ready);
 	//SpaceChromosome* c=&best_space_chromosome;
 	Solution* c=&best_solution;
+	
+	bool report=true;
+	
+	int added=0, duplicates=0;
 
 	//lock selected activities
 	for(int j=0; j<gt.rules.nHoursPerDay; j++){
@@ -199,72 +203,75 @@ void TimetableViewRoomsForm::lock(bool lockTime, bool lockSpace)
 					int time=c->times[ai];
 					int hour=time/gt.rules.nDaysPerWeek;
 					int day=time%gt.rules.nDaysPerWeek;
-					//Activity* act=gt.rules.activitiesList.at(ai);
+
 					Activity* act=&gt.rules.internalActivitiesList[ai];
 					if(lockTime){
 						ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(100.0, act->id, day, hour);
 						bool t=gt.rules.addTimeConstraint(ctr);
+						
 						if(t)
-							QMessageBox::information(this, QObject::tr("FET information"), 
-							 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
+							added++;
+						else
+							duplicates++;
+						
+						QString s;
+						
+						if(t)
+							s=tr("Added the following constraint:")+"\n"+ctr->getDetailedDescription(gt.rules);
 						else{
-							QMessageBox::warning(this, QObject::tr("FET information"),
-							 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
+							s=tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules));
 							delete ctr;
 						}
+						
+						if(report){
+							int k;
+							if(t)
+								k=QMessageBox::information(this, tr("FET information"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+							else
+								k=QMessageBox::warning(this, tr("FET warning"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+																			 				 	
+		 					if(k==0)
+								report=false;
+						}
 					}
 					
 					int ri=c->rooms[ai];
 					if(ri!=UNALLOCATED_SPACE && lockSpace){
 						ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100.0, act->id, (gt.rules.internalRoomsList[ri])->name);
 						bool t=gt.rules.addSpaceConstraint(ctr);
+						
 						if(t)
-							QMessageBox::information(this, QObject::tr("FET information"), 
-							 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
+							added++;
+						else
+							duplicates++;
+
+						QString s;
+						
+						if(t)
+							s=tr("Added the following constraint:")+"\n"+ctr->getDetailedDescription(gt.rules);
 						else{
-							QMessageBox::warning(this, QObject::tr("FET information"), 
-							 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
+							s=tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules));
 							delete ctr;
 						}
-					}
-				}
-				
-				//ai=rooms_timetable_week2[i][k][j];
-				ai=UNALLOCATED_ACTIVITY;
-				if(ai!=UNALLOCATED_ACTIVITY){
-					int time=c->times[ai];
-					int hour=time/gt.rules.nDaysPerWeek;
-					int day=time%gt.rules.nDaysPerWeek;
-					//Activity* act=gt.rules.activitiesList.at(ai);
-					Activity* act=&gt.rules.internalActivitiesList[ai];
-					if(lockTime){
-						ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(100.0, act->id, day, hour);
-						bool t=gt.rules.addTimeConstraint(ctr);
-						if(t)
-							QMessageBox::information(this, QObject::tr("FET information"), 
-							 QObject::tr("Added the following constraint:\n%1").arg(ctr->getDetailedDescription(gt.rules)));
-						else{
-							QMessageBox::warning(this, QObject::tr("FET information"), 
-							 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
-							delete ctr;
-						}
-					}
-					
-					int ri=c->rooms[ai];
-					if(ri!=UNALLOCATED_SPACE && ri!=UNSPECIFIED_ROOM && lockSpace){
-						ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100.0, act->id, (gt.rules.internalRoomsList[ri])->name);
-						bool t=gt.rules.addSpaceConstraint(ctr);
-						if(t)
-							QMessageBox::information(this, QObject::tr("FET information"), 
-							 QObject::tr("Added the following constraint:\n%1").arg(ctr->getDetailedDescription(gt.rules)));
-						else{
-							QMessageBox::warning(this, QObject::tr("FET information"), 
-							 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
-							delete ctr;
+
+						if(report){
+							if(t)
+								k=QMessageBox::information(this, tr("FET information"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+							else
+								k=QMessageBox::warning(this, tr("FET warning"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+																			 				 	
+		 					if(k==0)
+								report=false;
 						}
 					}
 				}
 			}
 		}
 	}
+	
+	QMessageBox::information(this, tr("FET information"), tr("Added %1 locking constraints, ignored %2 duplicates").arg(added).arg(duplicates));
 }
