@@ -16,35 +16,46 @@
  ***************************************************************************/
 
 #include "timetableviewteachersform.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
-#include "fetmainform.h"
+
+#include "timetable_defs.h"
+#include "timetable.h"
+#include "solution.h"
+
 #include "fet.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtable.h>
+#include <q3table.h>
 #include <qapplication.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 #include <qstring.h>
-#include <qlistbox.h>
+#include <q3listbox.h>
 #include <qlabel.h>
-#include <qtable.h>
+#include <q3table.h>
+
+#include <QDesktopWidget>
 
 extern bool students_schedule_ready;
 extern bool teachers_schedule_ready;
 
-extern TimeChromosome best_time_chromosome;
+extern Solution best_solution;
 
 extern bool simulation_running;
 
 TimetableViewTeachersForm::TimetableViewTeachersForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	teachersListBox->clear();
 	for(int i=0; i<gt.rules.nInternalTeachers; i++)
 		teachersListBox->insertItem(gt.rules.internalTeachersList[i]->name);
@@ -57,7 +68,7 @@ TimetableViewTeachersForm::~TimetableViewTeachersForm()
 
 void TimetableViewTeachersForm::teacherChanged(const QString &teacherName)
 {
-	if(teacherName==NULL)
+	if(teacherName==QString::null)
 		return;
 
 	int teacherId=gt.rules.searchTeacher(teacherName);
@@ -73,7 +84,7 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 	QString s;
 	QString teachername;
 
-	if(teachersListBox->currentText()==NULL)
+	if(teachersListBox->currentText()==QString::null)
 		return;
 
 	teachername = teachersListBox->currentText();
@@ -82,12 +93,14 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 	teacherNameTextLabel->setText(s);
 
 	assert(gt.rules.initialized);
-	teachersTimetableTable->setNumRows(gt.rules.nHoursPerDay+1);
-	teachersTimetableTable->setNumCols(gt.rules.nDaysPerWeek+1);
+	teachersTimetableTable->setNumRows(gt.rules.nHoursPerDay);
+	teachersTimetableTable->setNumCols(gt.rules.nDaysPerWeek);
 	for(int j=0; j<gt.rules.nDaysPerWeek; j++)
-		teachersTimetableTable->setText(0, j+1, gt.rules.daysOfTheWeek[j]);
+		//teachersTimetableTable->setText(0, j+1, gt.rules.daysOfTheWeek[j]);
+		teachersTimetableTable->horizontalHeader()->setLabel(j, gt.rules.daysOfTheWeek[j]);
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
-		teachersTimetableTable->setText(i+1, 0, gt.rules.hoursOfTheDay[i]);
+		//teachersTimetableTable->setText(i+1, 0, gt.rules.hoursOfTheDay[i]);
+		teachersTimetableTable->verticalHeader()->setLabel(i, gt.rules.hoursOfTheDay[i]);
 
 	int teacher=gt.rules.searchTeacher(teachername);
 	if(teacher<0){
@@ -98,33 +111,26 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 		for(int j=0; j<gt.rules.nHoursPerDay; j++){
 			for(int k=0; k<gt.rules.nDaysPerWeek; k++){
 				s = "";
-				int ai=teachers_timetable_week1[teacher][k][j]; //activity index
+				int ai=teachers_timetable_weekly[teacher][k][j]; //activity index
 				//Activity* act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
 					Activity* act=&gt.rules.internalActivitiesList[ai];
 					assert(act!=NULL);
-					s += act->subjectName+" "+act->subjectTagName+"\n"; //added in version 3_9_16, on 16 Oct. 2004; suggested by Nicholas Robinson
+					s += act->subjectName+" "+act->activityTagName+"\n"; //added in version 3_9_16, on 16 Oct. 2004; suggested by Nicholas Robinson
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
 						s += (*it) + " ";
+
+					int r=best_solution.rooms[ai];
+					if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
+						s+=" ";
+						s+=QObject::tr("R:")+gt.rules.internalRoomsList[r]->name;
+					}
 				}
-				ai=teachers_timetable_week2[teacher][k][j]; //activity index
-				//act=gt.rules.activitiesList.at(ai);
-				//if(ai!=UNALLOCATED_ACTIVITY && !act->studentsNames.isEmpty())
-				//	s += "/ ";
-				if(ai!=UNALLOCATED_ACTIVITY){
-					Activity* act=&gt.rules.internalActivitiesList[ai];
-					assert(act!=NULL);
-					if(!act->studentsNames.isEmpty())
-						s+="/ ";
-					s += act->subjectName+" "+act->subjectTagName+"\n"; //added in version 3_9_16, on 16 Oct. 2004; suggested by Nicholas Robinson
-					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						s += (*it) + " ";
-				}
-				teachersTimetableTable->setText(j+1, k+1, s);
+				teachersTimetableTable->setText(j, k, s);
 			}
-		for(int i=0; i<=gt.rules.nHoursPerDay; i++) //added in version 3_9_16, on 16 Oct. 2004
-			teachersTimetableTable->adjustRow(i);
 		}
+		for(int i=0; i<gt.rules.nHoursPerDay; i++) //added in version 3_9_16, on 16 Oct. 2004
+			teachersTimetableTable->adjustRow(i);
 	}
 }
 
@@ -134,7 +140,7 @@ void TimetableViewTeachersForm::detailActivity(int row, int col){
 	QString s;
 	QString teachername;
 
-	if(teachersListBox->currentText()==NULL)
+	if(teachersListBox->currentText()==QString::null)
 		return;
 
 	teachername = teachersListBox->currentText();
@@ -149,31 +155,47 @@ void TimetableViewTeachersForm::detailActivity(int row, int col){
 			QObject::tr("The teacher is invalid"));
 	}
 	else{
-		int j=row-1;
-		int k=col-1;
+		int j=row;
+		int k=col;
 		s = "";
 		if(j>=0 && k>=0){
-			int ai=teachers_timetable_week1[teacher][k][j]; //activity index
+			int ai=teachers_timetable_weekly[teacher][k][j]; //activity index
 			//Activity* act=gt.rules.activitiesList.at(ai);
 			if(ai!=UNALLOCATED_ACTIVITY){
 				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
-				s += act->getDetailedDescriptionWithConstraints(gt.rules);
-			}
-			ai=teachers_timetable_week2[teacher][k][j]; //activity index
-			//act=gt.rules.activitiesList.at(ai);
-			if(ai!=UNALLOCATED_ACTIVITY){
-				Activity* act=&gt.rules.internalActivitiesList[ai];
-				assert(act!=NULL);
-				s += "/\n";
-				s += act->getDetailedDescriptionWithConstraints(gt.rules);
+				//s += act->getDetailedDescriptionWithConstraints(gt.rules);
+				s += act->getDetailedDescription(gt.rules);
+
+				//int r=rooms_timetable_weekly[teacher][k][j];
+				int r=best_solution.rooms[ai];
+				if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
+					s+="\n";
+					s+=QObject::tr("Room: ")+gt.rules.internalRoomsList[r]->name;
+					s+="\n";
+				}
 			}
 		}
 		detailsTextEdit->setText(s);
 	}
 }
 
-void TimetableViewTeachersForm::lock()
+void TimetableViewTeachersForm::lockTime()
+{
+	this->lock(true, false);
+}
+	
+void TimetableViewTeachersForm::lockSpace()
+{
+	this->lock(false, true);
+}
+
+void TimetableViewTeachersForm::lockTimeSpace()
+{
+	this->lock(true, true);
+}
+			
+void TimetableViewTeachersForm::lock(bool lockTime, bool lockSpace)
 {
 	if(simulation_running){
 		QMessageBox::information(this, QObject::tr("FET information"),
@@ -184,56 +206,98 @@ void TimetableViewTeachersForm::lock()
 	//find teacher index
 	QString teachername;
 
-	if(teachersListBox->currentText()==NULL)
+	if(teachersListBox->currentText()==QString::null)
 		return;
 
 	teachername = teachersListBox->currentText();
 	int i=gt.rules.searchTeacher(teachername);
 
-	TimeChromosome* tc=&best_time_chromosome;
+	Solution* tc=&best_solution;
+	
+	bool report=true;
+	
+	int added=0, duplicates=0;
 
 	//lock selected activities
 	for(int j=0; j<gt.rules.nHoursPerDay; j++){
 		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
-			if(teachersTimetableTable->isSelected(j+1, k+1)){
-				int ai=teachers_timetable_week1[i][k][j];
+			if(teachersTimetableTable->isSelected(j, k)){
+				int ai=teachers_timetable_weekly[i][k][j];
 				if(ai!=UNALLOCATED_ACTIVITY){
 					int time=tc->times[ai];
 					int hour=time/gt.rules.nDaysPerWeek;
 					int day=time%gt.rules.nDaysPerWeek;
 					//Activity* act=gt.rules.activitiesList.at(ai);
 					Activity* act=&gt.rules.internalActivitiesList[ai];
-					ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(1, true, act->id, day, hour);
-					bool t=gt.rules.addTimeConstraint(ctr);
-					if(t)
-						QMessageBox::information(this, QObject::tr("FET information"), 
-						 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
-					else{
-						QMessageBox::warning(this, QObject::tr("FET information"), 
-						 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
-						delete ctr;
+
+					if(lockTime){
+						ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(100.0, act->id, day, hour);
+						bool t=gt.rules.addTimeConstraint(ctr);
+						
+						if(t)
+							added++;
+						else
+							duplicates++;
+
+						QString s;
+						
+						if(t)
+							s=tr("Added the following constraint:")+"\n"+ctr->getDetailedDescription(gt.rules);
+						else{
+							s=tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules));
+							delete ctr;
+						}
+						
+						if(report){
+							int k;
+							if(t)
+								k=QMessageBox::information(this, tr("FET information"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+							else
+								k=QMessageBox::warning(this, tr("FET warning"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+																			 				 	
+		 					if(k==0)
+								report=false;
+						}
 					}
-				}
-				
-				ai=teachers_timetable_week2[i][k][j];
-				if(ai!=UNALLOCATED_ACTIVITY){
-					int time=tc->times[ai];
-					int hour=time/gt.rules.nDaysPerWeek;
-					int day=time%gt.rules.nDaysPerWeek;
-					//Activity* act=gt.rules.activitiesList.at(ai);
-					Activity* act=&gt.rules.internalActivitiesList[ai];
-					ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(1, true, act->id, day, hour);
-					bool t=gt.rules.addTimeConstraint(ctr);
-					if(t)
-						QMessageBox::information(this, QObject::tr("FET information"), 
-						 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
-					else{
-						QMessageBox::warning(this, QObject::tr("FET information"), 
-						 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
-						delete ctr;
+					
+					int ri=tc->rooms[ai];
+					if(ri!=UNALLOCATED_SPACE && ri!=UNSPECIFIED_ROOM && lockSpace){
+						ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100, act->id, (gt.rules.internalRoomsList[ri])->name);
+						bool t=gt.rules.addSpaceConstraint(ctr);
+
+						QString s;
+						
+						if(t)
+							added++;
+						else
+							duplicates++;
+
+						if(t)
+							s=tr("Added the following constraint:")+"\n"+ctr->getDetailedDescription(gt.rules);
+						else{
+							s=tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules));
+							delete ctr;
+						}
+						
+						if(report){
+							int k;
+							if(t)
+								k=QMessageBox::information(this, tr("FET information"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+							else
+								k=QMessageBox::warning(this, tr("FET warning"), s,
+							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+																			 				 	
+		 					if(k==0)
+								report=false;
+						}
 					}
 				}
 			}
 		}
 	}
+	
+	QMessageBox::information(this, tr("FET information"), tr("Added %1 locking constraints, ignored %2 duplicates").arg(added).arg(duplicates));
 }
